@@ -4,13 +4,20 @@ coef.rma <- function(object, ...) {
 
    .chkclass(class(object), must="rma")
 
+   ddd <- list(...)
+
    coefs <- c(object$beta)
    names(coefs) <- rownames(object$beta)
 
+   if (isTRUE(ddd$type=="beta"))
+      return(coefs)
+
    if (inherits(object, "rma.ls")) {
       coefs <- list(beta=coefs)
       coefs$alpha <- c(object$alpha)
       names(coefs$alpha) <- rownames(object$alpha)
+      if (isTRUE(ddd$type=="alpha"))
+         return(coefs$alpha)
    }
 
    if (inherits(object, "rma.uni.selmodel")) {
@@ -21,6 +28,8 @@ coef.rma <- function(object, ...) {
       } else {
          names(coefs$delta) <- paste0("delta.", seq_along(object$delta))
       }
+      if (isTRUE(ddd$type=="delta"))
+         return(coefs$delta)
    }
 
    return(coefs)
