@@ -1,6 +1,6 @@
 funnel.default <- function(x, vi, sei, ni, subset, yaxis="sei", xlim, ylim, xlab, ylab, slab,
 steps=5, at, atransf, targs, digits, level=95,
-back="lightgray", shade="white", hlines="white",
+back, shade, hlines,
 refline=0, lty=3, pch, col, bg,
 label=FALSE, offset=0.4, legend=FALSE, ...) {
 
@@ -23,6 +23,26 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    atransf.char <- deparse(atransf)
 
+   if (anyNA(level) || is.null(level))
+      stop(mstyle$stop("Argument 'level' cannot be NA or NULL."))
+
+   .start.plot()
+
+   if (missing(back))
+      back <- .coladj(par("bg","fg"), dark=0.1, light=-0.2)
+
+   if (missing(shade))
+      shade <- .coladj(par("bg","fg"), dark=c(0.2,-0.8), light=c(0,1))
+
+   if (length(level) > 1L && length(shade) == 1L)
+      shade <- rep(shade, length(level))
+
+   if (missing(hlines))
+      hlines <- par("bg")
+
+   if (is.null(refline))
+      refline <- NA
+
    if (missing(pch))
       pch <- 19
 
@@ -39,7 +59,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       if (is.null(ni))
          ni <- attr(yi, "ni")
       if (!is.null(ni) && length(ni) != k)
-      stop(mstyle$stop(paste0("Length of the 'ni' argument (", length(ni), ") does not correspond to the number of outcomes (", k, ").")))
+         stop(mstyle$stop(paste0("Length of the 'ni' argument (", length(ni), ") does not correspond to the number of outcomes (", k, ").")))
       if (is.null(ni))
          stop(mstyle$stop("No sample size information available."))
    }
@@ -144,14 +164,14 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       if (yaxis == "wi")
          digits <- c(2L,2L)
    } else {
-      if (length(digits) == 1L)     ### digits[1] for x-axis labels
-         digits <- c(digits,digits) ### digits[2] for y-axis labels
+      if (length(digits) == 1L)     # digits[1] for x-axis labels
+         digits <- c(digits,digits) # digits[2] for y-axis labels
    }
 
-   ### note: digits can also be a list (e.g., digits=list(2L,3)); trailing 0's are dropped for intergers
+   ### note: digits can also be a list (e.g., digits=list(2L,3)); trailing 0's are dropped for integers
 
    if (length(lty) == 1L)
-      lty <- rep(lty, 2L) ### 1st value = funnel lines, 2nd value = reference line
+      lty <- rep(lty, 2L) # 1st value = funnel lines, 2nd value = reference line
 
    if (length(pch) == 1L) {
       pch.vec <- FALSE
@@ -163,7 +183,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       stop(mstyle$stop(paste0("Length of the 'pch' argument (", length(pch), ") does not correspond to the number of outcomes (", k, ").")))
 
    if (missing(col))
-      col <- "black"
+      col <- par("fg")
    if (length(col) == 1L) {
       col.vec <- FALSE
       col <- rep(col, k)
@@ -174,7 +194,8 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       stop(mstyle$stop(paste0("Length of the 'col' argument (", length(col), ") does not correspond to the number of outcomes (", k, ").")))
 
    if (missing(bg))
-      bg <- "white"
+      bg <- .coladj(par("bg","fg"), dark=0.1, light=-0.1)
+
    if (length(bg) == 1L) {
       bg.vec <- FALSE
       bg <- rep(bg, k)
@@ -192,15 +213,15 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
    if (!is.null(ddd$transf))
       warning("Function does not have a 'transf' argument (use 'atransf' instead).", call.=FALSE, immediate.=TRUE)
 
-   lplot     <- function(..., refline2, level2, lty2, transf, ci.res) plot(...)
-   labline   <- function(..., refline2, level2, lty2, transf, ci.res) abline(...)
-   lsegments <- function(..., refline2, level2, lty2, transf, ci.res) segments(...)
-   laxis     <- function(..., refline2, level2, lty2, transf, ci.res) axis(...)
-   lpolygon  <- function(..., refline2, level2, lty2, transf, ci.res) polygon(...)
-   llines    <- function(..., refline2, level2, lty2, transf, ci.res) lines(...)
-   lpoints   <- function(..., refline2, level2, lty2, transf, ci.res) points(...)
-   lrect     <- function(..., refline2, level2, lty2, transf, ci.res) rect(...)
-   ltext     <- function(..., refline2, level2, lty2, transf, ci.res) text(...)
+   lplot     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) plot(...)
+   labline   <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) abline(...)
+   lsegments <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) segments(...)
+   laxis     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) axis(...)
+   lpolygon  <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) polygon(...)
+   llines    <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) lines(...)
+   lpoints   <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) points(...)
+   lrect     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) rect(...)
+   ltext     <- function(..., refline2, level2, lty2, colci, colref, colbox, transf, ci.res) text(...)
 
    ### refline2, level2, and lty2 for adding a second reference line / funnel
 
@@ -230,6 +251,26 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       ci.res <- 1000
    }
 
+   ### to adjust color of reference line, region bounds, and the L box
+
+   if (!is.null(ddd$colref)) {
+      colref <- ddd$colref
+   } else {
+      colref <- .coladj(par("bg","fg"), dark=0.6, light=-0.6)
+   }
+
+   if (!is.null(ddd$colci)) {
+      colci <- ddd$colci
+   } else {
+      colci <- .coladj(par("bg","fg"), dark=0.6, light=-0.6)
+   }
+
+   if (!is.null(ddd$colbox)) {
+      colbox <- ddd$colbox
+   } else {
+      colbox <- .coladj(par("bg","fg"), dark=0.6, light=-0.6)
+   }
+
    #########################################################################
 
    ### if a subset of studies is specified
@@ -361,8 +402,8 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
       level     <- ifelse(level == 0, 1, ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)))
       level2    <- ifelse(level2 == 0, 1, ifelse(level2 >= 1, (100-level2)/100, ifelse(level2 > .5, 1-level2, level2)))
-      #level    <- ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)) ### note: there may be multiple level values
-      level.min <- min(level)                                                              ### note: smallest level is the widest CI
+      #level    <- ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)) # note: there may be multiple level values
+      level.min <- min(level)                                                              # note: smallest level is the widest CI
       lvals     <- length(level)
 
       ### calculate the CI bounds at the bottom of the figure (for the widest CI if there are multiple)
@@ -385,12 +426,12 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
       }
 
       if (missing(xlim)) {
-         xlim    <- c(min(x.lb.bot,min(yi)), max(x.ub.bot,max(yi))) ### make sure x-axis not only includes widest CI, but also all yi values
-         rxlim   <- xlim[2] - xlim[1]        ### calculate range of the x-axis limits
-         xlim[1] <- xlim[1] - (rxlim * 0.10) ### subtract 10% of range from lower x-axis bound
-         xlim[2] <- xlim[2] + (rxlim * 0.10) ### add      10% of range to   upper x-axis bound
+         xlim    <- c(min(x.lb.bot,min(yi),na.rm=TRUE), max(x.ub.bot,max(yi),na.rm=TRUE)) # make sure x-axis not only includes widest CI, but also all yi values
+         rxlim   <- xlim[2] - xlim[1]        # calculate range of the x-axis limits
+         xlim[1] <- xlim[1] - (rxlim * 0.10) # subtract 10% of range from lower x-axis bound
+         xlim[2] <- xlim[2] + (rxlim * 0.10) # add      10% of range to   upper x-axis bound
       } else {
-         xlim <- sort(xlim) ### just in case the user supplies the limits in the wrong order
+         xlim <- sort(xlim) # just in case the user supplies the limits in the wrong order
       }
 
    }
@@ -399,11 +440,11 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
       if (missing(xlim)) {
          xlim    <- c(min(yi), max(yi))
-         rxlim   <- xlim[2] - xlim[1]        ### calculate range of the x-axis limits
-         xlim[1] <- xlim[1] - (rxlim * 0.10) ### subtract 10% of range from lower x-axis bound
-         xlim[2] <- xlim[2] + (rxlim * 0.10) ### add      10% of range to   upper x-axis bound
+         rxlim   <- xlim[2] - xlim[1]        # calculate range of the x-axis limits
+         xlim[1] <- xlim[1] - (rxlim * 0.10) # subtract 10% of range from lower x-axis bound
+         xlim[2] <- xlim[2] + (rxlim * 0.10) # add      10% of range to   upper x-axis bound
       } else {
-         xlim <- sort(xlim) ### just in case the user supplies the limits in the wrong order
+         xlim <- sort(xlim) # just in case the user supplies the limits in the wrong order
       }
 
    }
@@ -428,7 +469,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    ### add y-axis
 
-   laxis(side=2, at=seq(from=ylim[1], to=ylim[2], length.out=steps), labels=formatC(seq(from=ylim[1], to=ylim[2], length.out=steps), digits=digits[[2]], format="f", drop0trailing=is.integer(digits[[2]])), ...)
+   laxis(side=2, at=seq(from=ylim[1], to=ylim[2], length.out=steps), labels=fmtx(seq(from=ylim[1], to=ylim[2], length.out=steps), digits[[2]], drop0ifint=TRUE), ...)
 
    ### add horizontal lines
 
@@ -456,13 +497,13 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
       if (yaxis == "seinv") {
          rylim   <- ylim[2] - ylim[1]
-         #ylim[1] <- max(.0001, ylim[1] - (rylim * 0.10)) ### not clear how much to add to bottom
+         #ylim[1] <- max(.0001, ylim[1] - (rylim * 0.10)) # not clear how much to add to bottom
          ylim[2] <- ylim[2] + (rylim * 0.10)
       }
 
       if (yaxis == "vinv") {
          rylim   <- ylim[2] - ylim[1]
-         #ylim[1] <- max(.0001, ylim[1] - (rylim * 0.10)) ### not clear how much to add to bottom
+         #ylim[1] <- max(.0001, ylim[1] - (rylim * 0.10)) # not clear how much to add to bottom
          ylim[2] <- ylim[2] + (rylim * 0.10)
       }
 
@@ -486,8 +527,8 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
          ci.right <- refline + qnorm(level[m]/2, lower.tail=FALSE) * sqrt(vi.vals)
 
          lpolygon(c(ci.left,ci.right[ci.res:1]), c(yi.vals,yi.vals[ci.res:1]), border=NA, col=shade[m], ...)
-         llines(ci.left,  yi.vals, lty=lty[1], ...)
-         llines(ci.right, yi.vals, lty=lty[1], ...)
+         llines(ci.left,  yi.vals, lty=lty[1], col=colci, ...)
+         llines(ci.right, yi.vals, lty=lty[1], col=colci, ...)
 
       }
 
@@ -495,8 +536,8 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
          ci.left  <- refline2 - qnorm(level2/2, lower.tail=FALSE) * sqrt(vi.vals)
          ci.right <- refline2 + qnorm(level2/2, lower.tail=FALSE) * sqrt(vi.vals)
-         llines(ci.left,  yi.vals, lty=lty2, ...)
-         llines(ci.right, yi.vals, lty=lty2, ...)
+         llines(ci.left,  yi.vals, lty=lty2, col=colci, ...)
+         llines(ci.right, yi.vals, lty=lty2, col=colci, ...)
 
       }
 
@@ -506,10 +547,10 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
    ### use segments so that line does not extent beyond tip of CI region
 
    if (is.element(yaxis, c("sei", "vi", "seinv", "vinv")))
-      lsegments(refline, ylim[1], refline, ylim[2], lty=lty[2], ...)
+      lsegments(refline, ylim[1], refline, ylim[2], lty=lty[2], col=colref, ...)
 
    if (is.element(yaxis, c("ni", "ninv", "sqrtni", "sqrtninv", "lni", "wi")))
-      labline(v=refline, lty=lty[2], ...)
+      labline(v=refline, lty=lty[2], col=colref, ...)
 
    #########################################################################
 
@@ -553,7 +594,8 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    ### add L-shaped box around plot
 
-   box(bty="l")
+   if (!is.na(colbox))
+      box(bty="l", col=colbox)
 
    ### generate x-axis positions if none are specified
 
@@ -570,12 +612,12 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    if (is.function(atransf)) {
       if (is.null(targs)) {
-         at.lab <- formatC(sapply(at.lab, atransf), digits=digits[[1]], format="f", drop0trailing=is.integer(digits[[1]]))
+         at.lab <- fmtx(sapply(at.lab, atransf), digits[[1]], drop0ifint=TRUE)
       } else {
-         at.lab <- formatC(sapply(at.lab, atransf, targs), digits=digits[[1]], format="f", drop0trailing=is.integer(digits[[1]]))
+         at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[1]], drop0ifint=TRUE)
       }
    } else {
-      at.lab <- formatC(at.lab, digits=digits[[1]], format="f", drop0trailing=is.integer(digits[[1]]))
+      at.lab <- fmtx(at.lab, digits[[1]], drop0ifint=TRUE)
    }
 
    ### add x-axis
@@ -590,6 +632,9 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    if (is.numeric(label) || is.character(label) || .isTRUE(label)) {
 
+      if (is.na(refline))
+         refline <- mean(yi, na.rm=TRUE)
+
       if (is.numeric(label)) {
          label <- round(label)
          if (label < 0)
@@ -618,60 +663,7 @@ label=FALSE, offset=0.4, legend=FALSE, ...) {
 
    ### add legend (if requested)
 
-   if (is.logical(legend) && isTRUE(legend))
-      lpos <- "topright"
-
-   if (is.character(legend)) {
-      lpos <- legend
-      legend <- TRUE
-   }
-
-   if (legend && !is.element(yaxis, c("sei", "vi", "seinv", "vinv"))) {
-      legend <- FALSE
-      warning(mstyle$warning("Argument 'legend' only applicable if 'yaxis' is 'sei', 'vi', 'seinv', or 'vinv'."), call.=FALSE)
-   }
-
-   if (legend) {
-
-      level <- c(level, 0)
-      lvals <- length(level)
-
-      add.studies <- !pch.vec && !col.vec && !bg.vec # only add 'Studies' to legend if pch, col, and bg were not vectors to begin with
-
-      scipen <- options(scipen=100)
-      lchars <- max(nchar(level))-2
-      options(scipen=scipen$scipen)
-
-      pval1 <- NULL
-      pval2 <- NULL
-      phantom <- NULL
-
-      ltxt <- sapply(seq_len(lvals), function(i) {
-         if (i == 1)
-            return(as.expression(bquote(paste(.(pval1) < p, phantom() <= .(pval2)), list(pval1=.fcf(level[i], lchars), pval2=.fcf(1, lchars)))))
-            #return(as.expression(bquote(p > .(pval), list(pval=.fcf(level[i], lchars)))))
-         if (i > 1 && i < lvals)
-            return(as.expression(bquote(paste(.(pval1) < p, phantom() <= .(pval2)), list(pval1=.fcf(level[i], lchars), pval2=.fcf(level[i-1], lchars)))))
-         if (i == lvals)
-            return(as.expression(bquote(paste(.(pval1) < p, phantom() <= .(pval2)), list(pval1=.fcf(0, lchars), pval2=.fcf(level[i-1], lchars)))))
-      })
-
-      pch.l  <- rep(22, lvals)
-      col.l  <- rep("black", lvals)
-      pt.cex <- rep(2, lvals)
-      pt.bg  <- c(shade, back)
-
-      if (add.studies) {
-         ltxt   <- c(ltxt, expression(plain(Studies)))
-         pch.l  <- c(pch.l, pch[1])
-         col.l  <- c(col.l, col[1])
-         pt.cex <- c(pt.cex, 1)
-         pt.bg  <- c(pt.bg, bg[1])
-      }
-
-      legend(lpos, inset=.01, bg="white", pch=pch.l, col=col.l, pt.cex=pt.cex, pt.bg=pt.bg, legend=ltxt)
-
-   }
+   .funnel.legend(legend, level, shade, back, yaxis, trimfill=FALSE, pch, col, bg, pch.fill=NA, pch.vec, col.vec, bg.vec, colci)
 
    ############################################################################
 
