@@ -17,15 +17,17 @@ add=x$add, to=x$to, transf, targs, pch=21, psize, plim=c(0.5,3.5), col, bg, grid
    if (!is.element(na.act, c("na.omit", "na.exclude", "na.fail", "na.pass")))
       stop(mstyle$stop("Unknown 'na.action' specified under options()."))
 
-   if (length(add) == 2L) ### for rma.mh and rma.peto objects (1st 'add' value applies to the individual outcomes)
+   if (length(add) == 2L) # for rma.mh and rma.peto objects (1st 'add' value applies to the individual outcomes)
       add <- add[1]
 
-   if (length(to) == 2L)  ### for rma.mh and rma.peto objects (1st 'to' value applies to the individual outcomes)
+   if (length(to) == 2L)  # for rma.mh and rma.peto objects (1st 'to' value applies to the individual outcomes)
       to <- to[1]
 
    if (!is.element(to, c("all","only0","if0all","none")))
       stop(mstyle$stop("Unknown 'to' argument specified."))
 
+   .start.plot()
+
    if (missing(transf))
       transf <- FALSE
 
@@ -38,7 +40,7 @@ add=x$add, to=x$to, transf, targs, pch=21, psize, plim=c(0.5,3.5), col, bg, grid
       psize <- NULL
 
    if (missing(lty)) {
-      lty <- c("solid", "dashed") ### 1st value = diagonal line, 2nd value = estimated effect line
+      lty <- c("solid", "dashed") # 1st value = diagonal line, 2nd value = estimated effect line
    } else {
       if (length(lty) == 1L)
          lty <- c(lty, lty)
@@ -56,7 +58,8 @@ add=x$add, to=x$to, transf, targs, pch=21, psize, plim=c(0.5,3.5), col, bg, grid
    ### grid argument can either be a logical or a color
 
    if (is.logical(grid))
-      gridcol <- "lightgray"
+      gridcol <- .coladj(par("bg","fg"), dark=c(0.2,-0.6), light=c(-0.2,0.6))
+
    if (is.character(grid)) {
       gridcol <- grid
       grid <- TRUE
@@ -87,7 +90,7 @@ add=x$add, to=x$to, transf, targs, pch=21, psize, plim=c(0.5,3.5), col, bg, grid
    }
 
    if (missing(col))
-      col <- "black"
+      col <- par("fg")
 
    if (length(col) == 1L)
       col <- rep(col, x$k.all)
@@ -98,7 +101,7 @@ add=x$add, to=x$to, transf, targs, pch=21, psize, plim=c(0.5,3.5), col, bg, grid
    col <- .getsubset(col, x$subset)
 
    if (missing(bg))
-      bg <- "gray"
+      bg <- .coladj(par("bg","fg"), dark=0.35, light=-0.35)
 
    if (length(bg) == 1L)
       bg <- rep(bg, x$k.all)
@@ -125,14 +128,14 @@ add=x$add, to=x$to, transf, targs, pch=21, psize, plim=c(0.5,3.5), col, bg, grid
    ### make sure that the corresponding arm-based yi values are also NA
 
    yi.is.na <- is.na(x$yi.f)
-   ai[yi.is.na]  <- NA
-   bi[yi.is.na]  <- NA
-   ci[yi.is.na]  <- NA
-   di[yi.is.na]  <- NA
-   x1i[yi.is.na] <- NA
-   x2i[yi.is.na] <- NA
-   t1i[yi.is.na] <- NA
-   t2i[yi.is.na] <- NA
+   ai[yi.is.na]  <- NA_real_
+   bi[yi.is.na]  <- NA_real_
+   ci[yi.is.na]  <- NA_real_
+   di[yi.is.na]  <- NA_real_
+   x1i[yi.is.na] <- NA_real_
+   x2i[yi.is.na] <- NA_real_
+   t1i[yi.is.na] <- NA_real_
+   t2i[yi.is.na] <- NA_real_
 
    options(na.action = "na.pass") ### to make sure dat.t and dat.c are of the same length
 
@@ -305,6 +308,7 @@ add=x$add, to=x$to, transf, targs, pch=21, psize, plim=c(0.5,3.5), col, bg, grid
    #########################################################################
 
    ### prepare data frame to return
+
    sav <- data.frame(x=dat.c$yi, y=dat.t$yi, cex=psize, pch=pch, col=col, bg=bg, ids=x$ids[not.na], slab=x$slab[not.na], stringsAsFactors=FALSE)
 
    invisible(sav)
