@@ -39,7 +39,7 @@ lty, lwd, col, level=99.99, refline=0, ...) {
       }
    }
 
-   level <- ifelse(level == 0, 1, ifelse(level >= 1, (100-level)/100, ifelse(level > .5, 1-level, level)))
+   level <- .level(level)
 
    ### get ... argument
 
@@ -51,6 +51,8 @@ lty, lwd, col, level=99.99, refline=0, ...) {
    addyi  <- ifelse(is.null(ddd$addyi),  TRUE,  ddd$addyi)
    addvi  <- ifelse(is.null(ddd$addvi),  TRUE,  ddd$addvi)
 
+   .start.plot()
+
    #########################################################################
 
    ### check if data argument has been specified
@@ -68,23 +70,17 @@ lty, lwd, col, level=99.99, refline=0, ...) {
    ### extract values, possibly from the data frame specified via data (arguments not specified are NULL)
 
    mf <- match.call()
-   mf.subset <- mf[[match("subset", names(mf))]]
-   mf.lty    <- mf[[match("lty",    names(mf))]]
-   mf.lwd    <- mf[[match("lwd",    names(mf))]]
-   mf.col    <- mf[[match("col",    names(mf))]]
-   subset <- eval(mf.subset, data, enclos=sys.frame(sys.parent()))
-   lty    <- eval(mf.lty,    data, enclos=sys.frame(sys.parent()))
-   lwd    <- eval(mf.lwd,    data, enclos=sys.frame(sys.parent()))
-   col    <- eval(mf.col,    data, enclos=sys.frame(sys.parent()))
+
+   subset  <- .getx("subset", mf=mf, data=data)
+   lty     <- .getx("lty",    mf=mf, data=data)
+   lwd     <- .getx("lwd",    mf=mf, data=data)
+   col     <- .getx("col",    mf=mf, data=data)
 
    if (measure == "GEN") {
 
-      mf.yi  <- mf[[match("yi",  names(mf))]]
-      mf.vi  <- mf[[match("vi",  names(mf))]]
-      mf.sei <- mf[[match("sei", names(mf))]]
-      yi  <- eval(mf.yi,  data, enclos=sys.frame(sys.parent()))
-      vi  <- eval(mf.vi,  data, enclos=sys.frame(sys.parent()))
-      sei <- eval(mf.sei, data, enclos=sys.frame(sys.parent()))
+      yi  <- .getx("yi",  mf=mf, data=data, checknumeric=TRUE)
+      vi  <- .getx("vi",  mf=mf, data=data, checknumeric=TRUE)
+      sei <- .getx("sei", mf=mf, data=data, checknumeric=TRUE)
 
       if (is.null(vi)) {
          if (is.null(sei)) {
@@ -94,10 +90,10 @@ lty, lwd, col, level=99.99, refline=0, ...) {
          }
       }
 
-      if (length(yi)==0L || length(vi)==0L)
-         stop(mstyle$stop("Cannot extract outcomes. Check that all of the required \n  information is specified via the appropriate arguments."))
+      if (!.all.specified(yi, vi))
+         stop(mstyle$stop("Cannot construct plot. Check that all of the required information is specified\n  via the appropriate arguments (i.e., yi, vi)."))
 
-      if (length(yi) != length(vi))
+      if (!.equal.length(yi, vi))
          stop(mstyle$stop("Supplied data vectors are not all of the same length."))
 
       k <- length(yi) ### number of outcomes before subsetting
@@ -105,42 +101,51 @@ lty, lwd, col, level=99.99, refline=0, ...) {
       ### subsetting
 
       if (!is.null(subset)) {
-         subset <- .setnafalse(subset, k=k)
-         yi <- yi[subset]
-         vi <- vi[subset]
+         subset <- .chksubset(subset, k)
+         yi <- .getsubset(yi, subset)
+         vi <- .getsubset(vi, subset)
       }
 
    }
 
    if (measure == "OR") {
 
-      mf.ai  <- mf[[match("ai",  names(mf))]]
-      mf.bi  <- mf[[match("bi",  names(mf))]]
-      mf.ci  <- mf[[match("ci",  names(mf))]]
-      mf.di  <- mf[[match("di",  names(mf))]]
-      mf.n1i <- mf[[match("n1i", names(mf))]]
-      mf.n2i <- mf[[match("n2i", names(mf))]]
-      ai  <- eval(mf.ai,  data, enclos=sys.frame(sys.parent()))
-      bi  <- eval(mf.bi,  data, enclos=sys.frame(sys.parent()))
-      ci  <- eval(mf.ci,  data, enclos=sys.frame(sys.parent()))
-      di  <- eval(mf.di,  data, enclos=sys.frame(sys.parent()))
-      n1i <- eval(mf.n1i, data, enclos=sys.frame(sys.parent()))
-      n2i <- eval(mf.n2i, data, enclos=sys.frame(sys.parent()))
-      if (is.null(bi)) bi <- n1i - ai
-      if (is.null(di)) di <- n2i - ci
+      ai  <- .getx("ai",  mf=mf, data=data, checknumeric=TRUE)
+      bi  <- .getx("bi",  mf=mf, data=data, checknumeric=TRUE)
+      ci  <- .getx("ci",  mf=mf, data=data, checknumeric=TRUE)
+      di  <- .getx("di",  mf=mf, data=data, checknumeric=TRUE)
+      n1i <- .getx("n1i", mf=mf, data=data, checknumeric=TRUE)
+      n2i <- .getx("n2i", mf=mf, data=data, checknumeric=TRUE)
 
-      if (length(ai)==0L || length(bi)==0L || length(ci)==0L || length(di)==0L)
-         stop(mstyle$stop("Cannot compute outcomes. Check that all of the required \n  information is specified via the appropriate arguments."))
-
-      if (!all(length(ai) == c(length(ai),length(bi),length(ci),length(di))))
+      if (!.equal.length(ai, bi, ci, di, n1i, n2i))
          stop(mstyle$stop("Supplied data vectors are not all of the same length."))
 
+      n1i.inc <- n1i != ai + bi
+      n2i.inc <- n2i != ci + di
+
+      if (any(n1i.inc, na.rm=TRUE))
+         stop(mstyle$stop("One or more 'n1i' values are not equal to 'ai + bi'."))
+      if (any(n2i.inc, na.rm=TRUE))
+         stop(mstyle$stop("One or more 'n2i' values are not equal to 'ci + di'."))
+
+      bi <- replmiss(bi, n1i-ai)
+      di <- replmiss(di, n2i-ci)
+
+      if (!.all.specified(ai, bi, ci, di))
+         stop(mstyle$stop("Cannot construct plot. Check that all of the required information is specified\n  via the appropriate arguments (i.e., ai, bi, ci, di or ai, n1i, ci, n2i)."))
+
+      n1i <- ai + bi
+      n2i <- ci + di
+
       if (any(c(ai > n1i, ci > n2i), na.rm=TRUE))
          stop(mstyle$stop("One or more event counts are larger than the corresponding group sizes."))
 
       if (any(c(ai, bi, ci, di) < 0, na.rm=TRUE))
          stop(mstyle$stop("One or more counts are negative."))
 
+      if (any(c(n1i < 0, n2i < 0), na.rm=TRUE))
+         stop(mstyle$stop("One or more group sizes are negative."))
+
       k <- length(ai) ### number of outcomes before subsetting
 
       ### note studies that have at least one zero cell
@@ -156,23 +161,23 @@ lty, lwd, col, level=99.99, refline=0, ...) {
       ### if drop00=TRUE, set counts to NA for studies that have no events (or all events) in both arms
 
       if (drop00) {
-         ai[id00] <- NA
-         bi[id00] <- NA
-         ci[id00] <- NA
-         di[id00] <- NA
+         ai[id00] <- NA_real_
+         bi[id00] <- NA_real_
+         ci[id00] <- NA_real_
+         di[id00] <- NA_real_
       }
 
       ### subsetting
 
       if (!is.null(subset)) {
-         subset <- .setnafalse(subset, k=k)
-         ai <- ai[subset]
-         bi <- bi[subset]
-         ci <- ci[subset]
-         di <- di[subset]
+         subset <- .chksubset(subset, k)
+         ai <- .getsubset(ai, subset)
+         bi <- .getsubset(bi, subset)
+         ci <- .getsubset(ci, subset)
+         di <- .getsubset(di, subset)
       }
 
-      dat <- escalc(measure="OR", ai=ai, bi=bi, ci=ci, di=di, drop00=drop00, onlyo1=onlyo1, addyi=addyi, addvi=addvi)
+      dat <- .do.call(escalc, measure="OR", ai=ai, bi=bi, ci=ci, di=di, drop00=drop00, onlyo1=onlyo1, addyi=addyi, addvi=addvi)
 
       yi <- dat$yi ### one or more yi/vi pairs may be NA/NA
       vi <- dat$vi ### one or more yi/vi pairs may be NA/NA
@@ -218,12 +223,12 @@ lty, lwd, col, level=99.99, refline=0, ...) {
    ### if a subset of studies is specified
 
    if (!is.null(subset)) {
-      ids  <- ids[subset]
-      lty  <- lty[subset]
-      lwd  <- lwd[subset]
-      col  <- col[subset]
-      id0  <- id0[subset]
-      id00 <- id00[subset]
+      ids  <- .getsubset(ids,  subset)
+      lty  <- .getsubset(lty,  subset)
+      lwd  <- .getsubset(lwd,  subset)
+      col  <- .getsubset(col,  subset)
+      id0  <- .getsubset(id0,  subset)
+      id00 <- .getsubset(id00, subset)
    }
 
    ### number of outcomes after subsetting
@@ -246,18 +251,20 @@ lty, lwd, col, level=99.99, refline=0, ...) {
       if (na.act == "na.omit" || na.act == "na.exclude" || na.act == "na.pass") {
          yi   <- yi[not.na]
          vi   <- vi[not.na]
-         ai   <- ai[not.na]
-         bi   <- bi[not.na]
-         ci   <- ci[not.na]
-         di   <- di[not.na]
+         if (measure == "OR") {
+            ai   <- ai[not.na]
+            bi   <- bi[not.na]
+            ci   <- ci[not.na]
+            di   <- di[not.na]
+            id0  <- id0[not.na]
+            id00 <- id00[not.na]
+         }
+         k    <- length(yi)
          ids  <- ids[not.na]
          lty  <- lty[not.na]
          lwd  <- lwd[not.na]
          col  <- col[not.na]
-         id0  <- id0[not.na]
-         id00 <- id00[not.na]
-         k    <- length(ai)
-         warning(mstyle$warning("Studies with NAs omitted from plotting."), call.=FALSE)
+         warning(mstyle$warning(paste(sum(has.na), ifelse(sum(has.na) > 1, "studies", "study"), "with NAs omitted from plotting.")), call.=FALSE)
       }
 
       if (na.act == "na.fail")
@@ -289,10 +296,12 @@ lty, lwd, col, level=99.99, refline=0, ...) {
    if (is.null(lwd))
       lwd <- seq(from=4.0, to=0.4, length.out=k)[rank(vi)]
 
-   ### set default line color (gray0 to gray60 according to the rank of vi)
+   ### set default line color (darker to lighter according to the rank of vi)
 
-   if (is.null(col))
-      col <- paste0("gray", round(seq(from=0, to=60, length.out=k))[rank(vi)])
+   if (is.null(col)) {
+      col <- sapply(seq(from=0.8, to=0.2, length.out=k), function(x) .coladj(par("bg","fg"), dark=x, light=-x))
+      col <- col[rank(vi)]
+   }
 
    ### set x-axis limits
 
@@ -339,12 +348,11 @@ lty, lwd, col, level=99.99, refline=0, ...) {
       lls.sum <- rep(NA_real_, k)
       for (i in seq_len(k)) {
          lls.sum[i] <- trapezoid(xs[!is.na(lls[i,])], lls[i,!is.na(lls[i,])])
+         lls[i,] <- lls[i,] / lls.sum[i]
       }
-      #lls.sum <- rowSums(lls, na.rm=TRUE)
-      lls <- apply(lls, 2, "/", lls.sum)
    }
 
-   lls[out] <- NA
+   lls[out] <- NA_real_
 
    ### set y-axis limits
 
@@ -354,7 +362,7 @@ lty, lwd, col, level=99.99, refline=0, ...) {
       ylim <- sort(ylim)
    }
 
-   plot(NA, NA, xlim=c(xlim[1], xlim[2]), ylim=ylim, xlab=xlab, ylab=ylab, ...)
+   plot(NA, NA, xlim=xlim, ylim=ylim, xlab=xlab, ylab=ylab, ...)
 
    for (i in seq_len(k)[order(1/vi)]) {
       lines(xs, lls[i,], lty=lty[i], lwd=lwd[i], col=col[i], ...)
