@@ -164,6 +164,7 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
          stop(mstyle$stop("Argument 'R' must be a correlation matrix, but contains values outside [-1,1]."))
 
       diag(R) <- 1
+      sdy <- 1
 
    }
 
@@ -236,17 +237,16 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
       vb  <- mse * invRxx
 
       R2    <- 1 - sse
-      R2adj <- 1 - (1 - R2) * ((n-1) / df)
+      R2adj <- 1 - (1 - R2) * ((n-ifelse(cov, 1, 0)) / df)
 
       F  <- c(value = (R2 / m) / mse, df1=m, df2=df)
       Fp <- pf(F[[1]], df1=m, df2=df, lower.tail=FALSE)
 
+      mse <- sdy^2 * (n-1) * (1 - R2) / df
+
       if (cov) {
 
-         mult <- sdy / sdx
-         b    <- b * mult
-         mse  <- sdy^2 * (n-1) * (1 - R2) / df
-
+         b <- b * sdy / sdx
          b <- rbind(means[y] - means[x] %*% b, b)
          rownames(b)[1] <- "intrcpt"
 
@@ -254,17 +254,16 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
          invXtX <- try(suppressWarnings(chol2inv(chol(XtX))), silent=TRUE)
 
          if (inherits(invXtX, "try-error")) {
-            vb <- matrix(NA, nrow=(m+1), ncol=(m+1))
+            vb <- matrix(NA_real_, nrow=(m+1), ncol=(m+1))
             warning(mstyle$warning("Cannot obtain var-cov matrix of the regression coefficients."), call.=FALSE)
          } else {
-            mse <- sdy^2 * (n-1) * (1 - R2) / df
-            vb  <- mse * invXtX
+            vb <- mse * invXtX
          }
 
          if (!has.means) {
-            b[1,]  <- NA
-            vb[1,] <- NA
-            vb[,1] <- NA
+            b[1,]  <- NA_real_
+            vb[1,] <- NA_real_
+            vb[,1] <- NA_real_
          }
 
       }
@@ -278,7 +277,7 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
       ci.lb <- c(b - crit * se)
       ci.ub <- c(b + crit * se)
 
-      res <- list(tab = data.frame(beta=b, se=se, tval=tval, df=df, pval=pval, ci.lb=ci.lb, ci.ub=ci.ub), vb=vb, R2=R2, R2adj=R2adj, F=F, Fdf=c(m,df), Fp=Fp, digits=digits, test="t")
+      res <- list(tab = data.frame(beta=b, se=se, tval=tval, df=df, pval=pval, ci.lb=ci.lb, ci.ub=ci.ub), vb=vb, R2=R2, R2adj=R2adj, F=F, Fdf=c(m,df), Fp=Fp, mse=mse, digits=digits, test="t")
 
    } else {
 
@@ -288,8 +287,7 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
 
       if (cov) {
 
-         mult <- sdy / sdx
-         b    <- b * mult
+         b <- b * sdy / sdx
 
          Rxy <- S[x, y, drop=FALSE]
          invRxx <- diag(1/sdx, nrow=m, ncol=m) %*% invRxx %*% diag(1/sdx, nrow=m, ncol=m)
@@ -302,7 +300,7 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
 
       }
 
-      U <- matrix(NA, nrow=p, ncol=p)
+      U <- matrix(NA_integer_, nrow=p, ncol=p)
       U[lower.tri(U, diag=Udiag)] <- seq_len(s)
       U[upper.tri(U, diag=Udiag)] <- t(U)[upper.tri(U, diag=Udiag)]
 
@@ -336,9 +334,9 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
          vb <- X %*% vb %*% t(X)
 
          if (!has.means) {
-            b[1,]  <- NA
-            vb[1,] <- NA
-            vb[,1] <- NA
+            b[1,]  <- NA_real_
+            vb[1,] <- NA_real_
+            vb[,1] <- NA_real_
          }
 
       }
@@ -357,13 +355,13 @@ matreg <- function(y, x, R, n, V, cov=FALSE, means, ztor=FALSE, nearpd=FALSE, le
       }
 
       if (inherits(QM, "try-error"))
-         QM <- NA
+         QM <- NA_real_
 
       QMp <- pchisq(QM, df=m, lower.tail=FALSE)
 
       rownames(vb) <- colnames(vb) <- rownames(b)
 
-      res <- list(tab = data.frame(beta=b, se=se, zval=zval, pval=pval, ci.lb=ci.lb, ci.ub=ci.ub), vb=vb, R2=R2, QM=QM, QMdf=c(m,NA), QMp=QMp, digits=digits, test="z")
+      res <- list(tab = data.frame(beta=b, se=se, zval=zval, pval=pval, ci.lb=ci.lb, ci.ub=ci.ub), vb=vb, R2=R2, QM=QM, QMdf=c(m,NA_integer_), QMp=QMp, digits=digits, test="z")
 
    }
 
