@@ -2,7 +2,7 @@
 
 ### c(m) calculation function for bias correction of SMDs (mi = n1i + n2i - 2) or SMCC/SMCRs (mi = ni - 1)
 
-.cmicalc <- function(mi) {
+.cmicalc <- function(mi, correct=TRUE) {
 
    ### this can overflow if mi is 'large' (on my machine, if mi >= 344)
    #cmi <- gamma(mi/2)/(sqrt(mi/2)*gamma((mi-1)/2))
@@ -10,8 +10,12 @@
    #is.na <- is.na(cmi)
    #cmi[is.na] <- 1 - 3/(4*mi[is.na] - 1)
 
-   ### this avoids the problem with overflow altogether
-   cmi <- ifelse(mi <= 1, NA, exp(lgamma(mi/2) - log(sqrt(mi/2)) - lgamma((mi-1)/2)))
+   if (correct) {
+      ### this avoids the problem with overflow altogether
+      cmi <- ifelse(mi <= 1, NA_real_, exp(lgamma(mi/2) - log(sqrt(mi/2)) - lgamma((mi-1)/2)))
+   } else {
+      cmi <- rep(1, length(mi))
+   }
    return(cmi)
 
 }
@@ -25,7 +29,7 @@
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
    if (!requireNamespace("mvtnorm", quietly=TRUE))
-      stop(mstyle$stop("Please install the 'mvtnorm' package to compute this measure."))
+      stop(mstyle$stop("Please install the 'mvtnorm' package to compute this measure."), call.=FALSE)
 
    fn <- function(par, ai, bi, ci, di, maxcor, fixcut=FALSE) {
 
@@ -101,7 +105,7 @@
 
    ### cases where only one cell is equal to zero are handled further below
 
-   ### in all other cases, first optimize over rho with cut values set to sample values
+   ### in all other cases, first optimize over rho with cut values set to the sample values
    ### use suppressWarnings() to suppress "NA/Inf replaced by maximum positive value" warnings
    res <- try(suppressWarnings(optimize(fn, interval=c(-1,1), ai=ai, bi=bi, ci=ci, di=di, maxcor=maxcor, fixcut=TRUE)), silent=TRUE)
 
@@ -112,7 +116,7 @@
    }
 
    ### then use the value as the starting point and maximize over rho and the cut values
-   ### (Nelder-Mead seems to do fine here; using L-BFGS-B doesn't seems to improve on this)
+   ### (Nelder-Mead seems to do fine here; using L-BFGS-B doesn't seem to improve on this)
    res <- try(optim(par=c(res$minimum,qnorm((ai+bi)/ni),qnorm((ai+ci)/ni)), fn, ai=ai, bi=bi, ci=ci, di=di, maxcor=maxcor, fixcut=FALSE, hessian=TRUE), silent=TRUE)
    #res <- try(optim(par=c(res$minimum,qnorm((ai+bi)/ni),qnorm((ai+ci)/ni)), fn, method="L-BFGS-B", lower=c(-1,-Inf,-Inf), upper=c(1,Inf,Inf), ai=ai, bi=bi, ci=ci, di=di, maxcor=maxcor, fixcut=FALSE, hessian=TRUE), silent=TRUE)
 
@@ -168,7 +172,7 @@
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
    if (!requireNamespace("gsl", quietly=TRUE))
-      stop(mstyle$stop("Please install the 'gsl' package to use measure='UCOR'."))
+      stop(mstyle$stop("Please install the 'gsl' package to use measure='UCOR'."), call.=FALSE)
 
    k.g <- length(g)
    k.x <- length(x)
@@ -202,16 +206,18 @@
 
 ### pdf of SMD (with or without bias correction)
 
-.dsmd <- function(x, n1, n2, theta, correct=TRUE, warn=FALSE) {
+.dsmd <- function(x, n1, n2, theta, correct=TRUE, xisg=FALSE, warn=FALSE) {
 
    nt <- n1 * n2 / (n1 + n2)
    m  <- n1 + n2 - 2
 
-   if (correct) {
-      cm <- .cmicalc(m)
-   } else {
+   cm <- .cmicalc(m)
+
+   if (xisg)
+      x <- x / cm
+
+   if (!correct)
       cm <- 1
-   }
 
    if (warn) {
       res <- dt(x * sqrt(nt) / cm, df = m, ncp = sqrt(nt) * theta) * sqrt(nt) / cm
@@ -283,4 +289,50 @@
 #integrate(function(x) .dzcor(x, n=5, rho=.8), lower=-100, upper=100)
 #integrate(function(x) x*.dzcor(x, n=5, rho=.8), lower=-100, upper=100)
 
+### pdf of ARAW
+
+.daraw <- function(x, n, m, alpha) {
+   res <- df((1-x)/(1-alpha), (n-1)*(m-1), (n-1)) / (1-alpha)
+   res[alpha >=  1] <- 0
+   res[alpha <= -1] <- 0
+   return(res)
+}
+
+#integrate(function(x) .daraw(x, n=10, m=2, alpha=.8), lower=-Inf, upper=Inf)
+#integrate(function(x) x*.daraw(x, n=10, m=2, alpha=.8), lower=-Inf, upper=Inf)
+
+############################################################################
+
+### function to convert p-values to t-statistics (need this to catch NULL
+### since sign(NULL) and qt(NULL) throw errors)
+
+.convp2t <- function(pval, df) {
+
+   if (is.null(pval))
+      return(NULL)
+
+   df <- ifelse(df < 1, NA, df)
+   pval <- ifelse(abs(pval) > 1, NA, pval)
+
+   sign(pval) * qt(abs(pval)/2, df=df, lower.tail=FALSE)
+
+}
+
+### function to convert p-values to F-statistics (need this to catch NULL
+### since qf(NULL) throws an error)
+
+.convp2f <- function(pval, df1, df2) {
+
+   if (is.null(pval))
+      return(NULL)
+
+   df1 <- ifelse(df1 < 1, NA, df1)
+   df2 <- ifelse(df2 < 1, NA, df2)
+   pval <- ifelse(pval < 0, NA, pval)
+   pval <- ifelse(pval > 1, NA, pval)
+
+   qf(pval, df1=df1, df2=df2, lower.tail=FALSE)
+
+}
+
 ############################################################################
