@@ -132,6 +132,11 @@
 
 ############################################################################
 
+### function to take the square root of a vector of numbers, giving NA for negative numbers (without a warning)
+
+.sqrt <- function(x)
+   sapply(x, function(x) if (is.na(x) || x < 0) NA_real_ else sqrt(x))
+
 ### function to obtain the trace of a matrix
 
 .tr <- function(X)
@@ -179,9 +184,17 @@
 .is.matrix <- function(x)
    is.matrix(x) || inherits(x, "Matrix")
 
+### function to test if x is numeric but also allow a (vector of) NA
+
+.is.numeric <- function(x) {
+   if (all(is.na(x)))
+      return(TRUE)
+   is.numeric(x)
+}
+
 ############################################################################
 
-### function to format p-values
+### function to format p-values (no longer used; use fmtp() instead)
 ### if showeq=FALSE, c(.001, .00001) becomes c("0.0010", "<.0001")
 ### if showeq=TRUE,  c(.001, .00001) becomes c("=0.0010", "<.0001")
 ### if add0=FALSE, "<.0001"; if add0=TRUE, "<0.0001"
@@ -192,18 +205,17 @@
    cutoff  <- paste(c(".", rep(0,digits-1),1), collapse="")
    ncutoff <- as.numeric(cutoff)
 
-   ifelse(is.na(p), paste0(ifelse(showeq, "=", ""), sep, NA),
+   ifelse(is.na(p), paste0(ifelse(showeq, "=", ""), sep, "NA"),
                     ifelse(p >= ncutoff, paste0(ifelse(showeq, "=", ""), sep, formatC(p, digits=digits, format="f")),
                                          paste0("<", sep, ifelse(add0, "0", ""), cutoff)))
 
 }
 
-### function to format/round values in general
+### function to format/round values in general (no longer used; use fmtx() instead)
 
 .fcf <- function(x, digits) {
 
    if (all(is.na(x))) { # since formatC(NA, format="f", digits=2) fails
-      #x
       rep("NA", length(x))
    } else {
       trimws(formatC(x, format="f", digits=digits))
@@ -292,26 +304,29 @@
 ############################################################################
 
 .space <- function(x=TRUE) {
-   no.rmspace <- !exists(".rmspace")
-   if (no.rmspace && x)
+   if (exists(".rmspace")) {
+      addspace <- FALSE
+   } else {
+      addspace <- isTRUE(getmfopt("space", default=TRUE))
+   }
+   if (addspace && x)
       cat("\n")
-   if (!no.rmspace && !x)
+   if (!addspace && !x)
       cat("\n")
 }
 
 .get.footsym <- function() {
 
-   if (exists(".footsym")) {
-      fs <- get(".footsym")
-   } else {
+   fs <- getmfopt("footsym")
+
+   if (is.null(fs) || length(fs) != 6L)
       fs <- c("\u00b9", "1)", "\u00b2", "2)", "\u00b3", "3)")
-   }
 
    return(fs)
 
 }
 
-# .footsym <- c("\u00b9", "\u00b9\u207e", "\u00b2", "\u00b2\u207e", "\u00b3", "\u00b3\u207e")
+# setmfopt(footsym = c("\u00b9", "\u00b9\u207e", "\u00b2", "\u00b2\u207e", "\u00b3", "\u00b3\u207e"))
 
 ############################################################################
 
@@ -374,21 +389,38 @@
 
 ############################################################################
 
-.getx <- function(x, mf, data, enclos=sys.frame(sys.parent(n=2)), checknull=TRUE, checknumeric=FALSE) {
+.getx <- function(x, mf, data, enclos=sys.frame(sys.parent(n=2)), checknull=TRUE, checknumeric=FALSE, default) {
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
+   mf.getx <- match.call()
+   dname <- deparse1(mf.getx[[match("data", names(mf.getx))]])
+   dname <- deparse1(mf[[match(dname, names(mf))]])
+
    mf.x <- mf[[match(x, names(mf))]]
-   out <- try(eval(mf.x, data, enclos), silent=TRUE) # NULL if x was not specifified
+
+   if (!is.null(dname) && dname %in% names(data) && grepl("$", deparse1(mf.x), fixed=TRUE) || grepl("[[", deparse1(mf.x), fixed=TRUE))
+      data <- NULL
+
+   out <- try(eval(mf.x, data, enclos), silent=TRUE) # NULL if x was not specified
 
    if (inherits(out, "try-error") || is.function(out))
       stop(mstyle$stop(paste0("Cannot find the object/variable ('", deparse(mf.x), "') specified for the '", x, "' argument.")), call.=FALSE)
 
    # note: is.function() check catches case where 'vi' is the utils::vi() function and other shenanigans
 
+   # check if x is actually one of the elements in the call
+
+   spec <- x %in% names(mf)
+
+   # out could be NULL if it is not a specified argument; if so, apply default if there is one
+
+   if (is.null(out) && !spec && !missing(default))
+      out <- default
+
    if (checknull) {
 
-      spec <- x %in% names(mf)
+      # when using something like fun(dat$blah) and blah doesn't exist in dat, then get NULL
 
       if (spec && is.null(out)) {
          mf.txt <- deparse(mf.x)
@@ -402,7 +434,7 @@
 
    }
 
-   if (checknumeric && !is.null(out) && !is.list(out) && !is.numeric(out[1])) # using [1] so is.numeric(Matrix(1:3)[1]) works
+   if (checknumeric && !is.null(out) && !is.list(out) && !.is.numeric(out[1])) # using [1] so is.numeric(Matrix(1:3)[1]) works
       stop(mstyle$stop(paste0("The object/variable specified for the '", x, "' argument is not numeric.")), call.=FALSE)
 
    return(out)
@@ -481,6 +513,11 @@
          ok <- FALSE
       if (any(grepl("^std", xl)))
          ok <- FALSE
+      # ends with 'se' or 'std'
+      if (any(grepl("se$", xl)))
+         ok <- FALSE
+      if (any(grepl("std$", xl)))
+         ok <- FALSE
       # catch cases where vi=<data frame>$se and vi=<data frame>$std
       if (any(grepl("^[[:alpha:]][[:alnum:]_.]*\\$se", xl)))
          ok <- FALSE
@@ -512,7 +549,7 @@
 .equal.length <- function(...) {
 
    ddd <- list(...)
-   ks <- lengths(ddd)    # get the length of each element in ddd
+   ks <- lengths(ddd)   # get the length of each element in ddd
    if (all(ks == 0L)) { # if all elements have length 0 (are NULL), return TRUE
       return(TRUE)
    } else {
@@ -596,6 +633,18 @@
             lab <- ifelse(short, lab, "Transformed Phi Coefficient")
          }
       }
+      if (measure == "ZPHI") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, expression('Fisher\'s ' * z[phi]), "Fisher's z Transformed Phi Coefficient")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Fisher's z Transformed Phi Coefficient")
+            funlist <- lapply(list(transf.ztor, transf.ztor.int, tanh), deparse)
+            if (any(sapply(funlist, identical, atransf.char)))
+               lab <- ifelse(short, "Phi", "Phi Coefficient")
+            if (any(sapply(funlist, identical, transf.char)))
+               lab <- ifelse(short, "Phi", "Phi Coefficient")
+         }
+      }
       if (measure == "YUQ") {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
             lab <- ifelse(short, "Yule's Q", "Yule's Q")
@@ -666,9 +715,21 @@
       }
       if (measure == "RPB") {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
-            lab <- ifelse(short, "Correlation", "Point-Biserial Correlation")
+            lab <- ifelse(short, "Correlation", "Point-Biserial Correlation Coefficient")
          } else {
-            lab <- ifelse(short, lab, "Transformed Point-Biserial Correlation")
+            lab <- ifelse(short, lab, "Transformed Point-Biserial Correlation Coefficient")
+         }
+      }
+      if (measure == "ZPB") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, expression('Fisher\'s ' * z[phi]), "Fisher's z Transformed Point-Biserial Correlation Coefficient")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Fisher's z Transformed Point-Biserial Correlation Coefficient")
+            funlist <- lapply(list(transf.ztor, transf.ztor.int, tanh), deparse)
+            if (any(sapply(funlist, identical, atransf.char)))
+               lab <- ifelse(short, "Correlation", "Point-Biserial Correlation Coefficient")
+            if (any(sapply(funlist, identical, transf.char)))
+               lab <- ifelse(short, "Correlation", "Point-Biserial Correlation Coefficient")
          }
       }
       if (measure == "CVR") {
@@ -703,7 +764,7 @@
             lab <- ifelse(short, lab, "Transformed Correlation Coefficient")
          }
       }
-      if (measure == "ZCOR") {
+      if (is.element(measure, c("ZCOR","ZTET","ZBIS"))) {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
             lab <- ifelse(short, expression('Fisher\'s ' * z[r]), "Fisher's z Transformed Correlation Coefficient")
          } else {
@@ -742,6 +803,38 @@
             lab <- ifelse(short, lab, "Transformed Semi-Partial Correlation Coefficient")
          }
       }
+      if (measure == "ZSPCOR") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, expression('Fisher\'s ' * z[r]), "Fisher's z Transformed Semi-Partial Correlation Coefficient")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Fisher's z Transformed Semi-Partial Correlation Coefficient")
+            funlist <- lapply(list(transf.ztor, transf.ztor.int, tanh), deparse)
+            if (any(sapply(funlist, identical, atransf.char)))
+               lab <- ifelse(short, "Correlation", "Semi-Partial Correlation Coefficient")
+            if (any(sapply(funlist, identical, transf.char)))
+               lab <- ifelse(short, "Correlation", "Semi-Partial Correlation Coefficient")
+         }
+      }
+      ######################################################################
+      if (measure == "R2") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, expression(R^2), "Coefficient of Determination")
+         } else {
+            lab <- ifelse(short, lab, "Transformed Coefficient of Determination")
+         }
+      }
+      if (measure == "ZR2") {
+         if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
+            lab <- ifelse(short, expression(z[R^2]), "z Transformed Coefficient of Determination")
+         } else {
+            lab <- ifelse(short, lab, "Transformed z Transformed Coefficient of Determination")
+            funlist <- lapply(list(transf.ztor2), deparse)
+            if (any(sapply(funlist, identical, atransf.char)))
+               lab <- ifelse(short, expression(R^2), "Coefficient of Determination")
+            if (any(sapply(funlist, identical, transf.char)))
+               lab <- ifelse(short, expression(R^2), "Coefficient of Determination")
+         }
+      }
       ######################################################################
       if (measure == "PR") {
          if (identical(transf.char, "FALSE") && identical(atransf.char, "FALSE")) {
@@ -984,9 +1077,9 @@
             lab <- ifelse(short, lab, "Transformed Log Relative Excess Heterozygosity")
             funlist <- lapply(list(exp, transf.exp.int), deparse)
             if (any(sapply(funlist, identical, atransf.char)))
-               lab <- ifelse(short, "Relative Excess Heterozygosity", "Relative Excess Heterozygosity (log scale)")
+               lab <- ifelse(short, "REH", "Relative Excess Heterozygosity (log scale)")
             if (any(sapply(funlist, identical, transf.char)))
-               lab <- ifelse(short, "Relative Excess Heterozygosity", "Relative Excess Heterozygosity")
+               lab <- ifelse(short, "REH", "Relative Excess Heterozygosity")
          }
       }
       ######################################################################
@@ -1007,12 +1100,18 @@
 
       if (exists(".mstyle")) {
          .mstyle <- get(".mstyle")
-         if (!is.list(.mstyle))
-            .mstyle <- list(.mstyle)
       } else {
          .mstyle <- list()
       }
 
+      styleopt <- getmfopt("style")
+
+      if (!is.null(styleopt))
+         .mstyle <- styleopt
+
+      if (!is.list(.mstyle))
+         .mstyle <- list(.mstyle)
+
       if (is.null(.mstyle$section)) {
          section <- crayon::bold
       } else {
@@ -1078,6 +1177,7 @@
    } else {
 
       tmp <- function(...) paste0(...)
+
       section <- tmp
       header  <- tmp
       body1   <- tmp
@@ -1115,8 +1215,8 @@
 
 .print.table <- function(x, mstyle) {
 
-   #is.header <- !grepl(" [-0-9]", x)
-   is.header <- !grepl("^\\s*[0-9]", x)
+   is.header <- !grepl(" [-0-9]", x)
+   #is.header <- !grepl("^\\s*[0-9]", x)
    has.header <- any(is.header)
 
    for (i in seq_along(x)) {
@@ -1189,6 +1289,14 @@
       res[c(na.omit(pos))] <- .digits[!is.na(pos)]
    }
 
+   if (!is.null(getmfopt("digits"))) {
+      .digits <- getmfopt("digits")
+      if (length(.digits) == 1L)
+         .digits <- c(est=.digits[[1]], se=.digits[[1]], test=.digits[[1]], pval=.digits[[1]], ci=.digits[[1]], var=.digits[[1]], sevar=.digits[[1]], fit=.digits[[1]], het=.digits[[1]])
+      pos <- pmatch(names(.digits), names(res))
+      res[c(na.omit(pos))] <- .digits[!is.na(pos)]
+   }
+
    if (!dmiss) {
       if (is.null(names(digits))) {
          res <- c(est=digits[[1]], se=digits[[1]], test=digits[[1]], pval=digits[[1]], ci=digits[[1]], var=digits[[1]], sevar=digits[[1]], fit=digits[[1]], het=digits[[1]])
@@ -1220,83 +1328,11 @@
 .isFALSE <- function(x)
    !is.null(x) && is.logical(x) && !is.na(x) && !x
 
-############################################################################
-
-### to register getfit method for 'rma.uni' and 'rma.mv' objects: eval(metafor:::.glmulti)
-
-.glmulti <- str2expression("
-
-if (!(\"glmulti\" %in% .packages()))
-   stop(\"Must load the 'glmulti' package first to use this code.\")
-
-setOldClass(\"rma.uni\")
-
-setMethod(\"getfit\", \"rma.uni\", function(object, ...) {
-   if (object$test==\"z\") {
-      cbind(estimate=coef(object), se=sqrt(diag(vcov(object))), df=Inf)
-   } else {
-      cbind(estimate=coef(object), se=sqrt(diag(vcov(object))), df=object$k-object$p)
-   }
-})
-
-setOldClass(\"rma.mv\")
-
-setMethod(\"getfit\", \"rma.mv\", function(object, ...) {
-   if (object$test==\"z\") {
-      cbind(estimate=coef(object), se=sqrt(diag(vcov(object))), df=Inf)
-   } else {
-      cbind(estimate=coef(object), se=sqrt(diag(vcov(object))), df=object$k-object$p)
-   }
-})
-
-setOldClass(\"rma.glmm\")
-
-setMethod(\"getfit\", \"rma.glmm\", function(object, ...) {
-   if (object$test==\"z\") {
-      cbind(estimate=coef(object), se=sqrt(diag(vcov(object))), df=Inf)
-   } else {
-      cbind(estimate=coef(object), se=sqrt(diag(vcov(object))), df=object$k-object$p)
-   }
-})
-
-")
-
-### helper functions to make MuMIn work together with metafor
-
-.MuMIn <- str2expression("
-
-makeArgs.rma <- function (obj, termNames, comb, opt, ...) {
-   ret <- MuMIn:::makeArgs.default(obj, termNames, comb, opt)
-   names(ret)[1L] <- \"mods\"
-   ret
-}
-
-coefTable.rma <- function (model, ...) {
-  MuMIn:::.makeCoefTable(model$b, model$se, coefNames = rownames(model$b))
-}
-
-")
-
-### helper functions to make mice work together with metafor (note: no longer
-### needed, as there are glance and tidy methods for rma objects in broom now)
-
-.mice <- str2expression("
-
-glance.rma <- function (x, ...)
-   data.frame(df.residual=df.residual(x))
-
-tidy.rma <- function (x, ...) {
-   ret <- coef(summary(x))
-   colnames(ret)[2] <- \"std.error\"
-   ret$term <- rownames(ret)
-   return(ret)
-}
-
-")
+# not sure anymore why I implemented these; c(isTRUE(NULL), isTRUE(NA), isFALSE(NULL), isFALSE(NA)) are all FALSE
 
 ############################################################################
 
-### shorten a string vector so that elements remain distinguishable
+### shorten a character vector so that elements remain distinguishable
 
 .shorten <- function(x, minlen) {
 
@@ -1354,9 +1390,14 @@ tidy.rma <- function (x, ...) {
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
+   argname <- deparse(substitute(x))
+
+   if (length(x) == 0L)
+      stop(mstyle$stop(paste0("Argument '", argname, "' is of length 0.")), call.=FALSE)
+
    if (is.logical(x)) {
       if (length(x) != k)
-         stop(mstyle$stop(paste0("Length of the specified 'subset' (", length(x), ") is not of length k = ", k, ".")), call.=FALSE)
+         stop(mstyle$stop(paste0("Length of the '", argname, "' argument (", length(x), ") is not of length k = ", k, ".")), call.=FALSE)
       #x <- x[seq_len(k)]     # keep only elements 1:k from x
       if (anyNA(x))           # if x includes any NA elements
          x[is.na(x)] <- FALSE # set NA elements to FALSE
@@ -1368,14 +1409,14 @@ tidy.rma <- function (x, ...) {
       x <- as.integer(round(x))
       x <- x[x != 0L]           # also remove any 0's
       if (any(x > 0L) && any(x < 0L))
-         stop(mstyle$stop("Cannot mix positive and negative values in 'subset'."), call.=FALSE)
+         stop(mstyle$stop(paste0("Cannot mix positive and negative values in '", argname, "' argument.")), call.=FALSE)
       if (all(x > 0L)) {
          if (any(x > k))
-            stop(mstyle$stop(paste0("Specified 'subset' includes values larger than k = ", k, ".")), call.=FALSE)
+            stop(mstyle$stop(paste0("Argument '", argname, "' includes values larger than k = ", k, ".")), call.=FALSE)
          x <- is.element(seq_len(k), x)
       } else {
          if (any(x < -k))
-            stop(mstyle$stop(paste0("Specified 'subset' includes values larger than k = ", k, ".")), call.=FALSE)
+            stop(mstyle$stop(paste0("Argument '", argname, "' includes values larger than k = ", k, ".")), call.=FALSE)
          x <- !is.element(seq_len(k), abs(x))
       }
    }
@@ -1392,7 +1433,7 @@ tidy.rma <- function (x, ...) {
 
 .getsubset <- function(x, subset, col=FALSE, drop=FALSE) {
 
-   if (is.null(x) || is.null(subset)) # if x or subset is NULL, return x (i.e., NULL)
+   if (is.null(x) || is.null(subset)) # if x or subset is NULL, return x
       return(x)
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
@@ -1426,7 +1467,7 @@ tidy.rma <- function (x, ...) {
 
 .wmean <- function (x, w, na.rm=FALSE) {
    if (na.rm) {
-      i <- !(is.na(x) | is.na(w))
+      i <- !(is.na(x) | is.na(w)) # only include x if x and w are not missing
       x <- x[i]
       w <- w[i]
    }
@@ -1435,84 +1476,6 @@ tidy.rma <- function (x, ...) {
 
 ############################################################################
 
-.tes.intfun <- function(x, theta, tau, sei, H0, alternative, crit) {
-   if (alternative == "two.sided")
-      pow <- (pnorm(crit, mean=(x-H0)/sei, sd=1, lower.tail=FALSE) + pnorm(-crit, mean=(x-H0)/sei, sd=1, lower.tail=TRUE))
-   if (alternative == "greater")
-      pow <- pnorm(crit, mean=(x-H0)/sei, sd=1, lower.tail=FALSE)
-   if (alternative == "less")
-      pow <- pnorm(crit, mean=(x-H0)/sei, sd=1, lower.tail=TRUE)
-   res <- pow * dnorm(x, theta, tau)
-   return(res)
-}
-
-.tes.lim <- function(theta, yi, vi, H0, alternative, alpha, tau2, test, tes.alternative, progbar, tes.alpha, correct, rel.tol, subdivisions, tau2.lb) {
-   pval <- tes(x=yi, vi=vi, H0=H0, alternative=alternative, alpha=alpha, theta=theta, tau2=tau2, test=test, tes.alternative=tes.alternative, progbar=progbar,
-                       tes.alpha=tes.alpha, correct=correct, rel.tol=rel.tol, subdivisions=subdivisions, tau2.lb=tau2.lb, find.lim=FALSE)$pval
-   #cat("theta = ", theta, " pval = ", pval, "\n")
-   return(pval - tes.alpha)
-}
-
-############################################################################
-
-.fsn.fisher <- function(fsnum, pi, alpha) {
-   k <- length(pi)
-   X2 <- -2*sum(log(c(pi, rep(0.5, fsnum))))
-   return(pchisq(X2, df=2*(k+fsnum), lower.tail=FALSE) - alpha)
-}
-
-.fsn.fitre <- function(yi, vi) {
-
-   k     <- length(yi)
-   wi    <- 1/vi
-   sumwi <- sum(wi)
-   est   <- sum(wi*yi)/sumwi
-   Q     <- sum(wi * (yi - est)^2)
-   tau2  <- max(0, (Q - (k-1)) / (sumwi - sum(wi^2)/sumwi))
-   wi    <- 1 / (vi + tau2)
-   sumwi <- sum(wi)
-   est   <- sum(wi*yi)/sumwi
-   se    <- sqrt(1 / sumwi)
-   zval  <- est / se
-   pval  <- 2*pnorm(abs(zval), lower.tail=FALSE)
-
-   return(list(est=est, se=se, zval=zval, pval=pval, tau2=tau2))
-
-}
-
-.fsn.fitnew <- function(new, yi, vi, vnew, tau2, alpha, iters) {
-
-   new <- ceiling(new)
-
-   mus   <- rep(NA_real_, iters)
-   pvals <- rep(NA_real_, iters)
-
-   for (j in seq_len(iters)) {
-      yinew <- c(yi, rnorm(new, 0, sqrt(vnew+tau2)))
-      vinew <- c(vi, rep(vnew, new))
-      tmp <- .fsn.fitre(yinew, vinew)
-      mus[j] <- tmp$est
-      pvals[j] <- tmp$pval
-   }
-
-   return(list(mean = mean(mus), rejrate = mean(pvals <= alpha)))
-
-}
-
-.fsn.re <- function(fsnum, yi, vi, vnew, tau2, target, alpha, iters, verbose=FALSE) {
-
-   fsnum <- ceiling(fsnum)
-   tmp <- .fsn.fitnew(fsnum, yi, vi, vnew, tau2, alpha, iters)
-   est <- tmp$mean
-   diff <- est - target
-   if (verbose)
-      cat("fsnum =", formatC(fsnum, width=4, format="d"), "  est =", .fcf(est, 4), "  target =", .fcf(target, 4),  "  diff =", formatC(diff, format="f", digits=4, flag=" "), "\n")
-   return(diff)
-
-}
-
-############################################################################
-
 .chkopt <- function(optimizer, optcontrol) {
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
@@ -1581,6 +1544,16 @@ tidy.rma <- function (x, ...) {
          stop(mstyle$stop("Please install the 'alabama' package to use this optimizer."), call.=FALSE)
    }
 
+   if (optimizer == "Rcgmin") {
+      if (!requireNamespace("Rcgmin", quietly=TRUE))
+         stop(mstyle$stop("Please install the 'Rcgmin' package to use this optimizer."), call.=FALSE)
+   }
+
+   if (optimizer == "Rvmmin") {
+      if (!requireNamespace("Rvmmin", quietly=TRUE))
+         stop(mstyle$stop("Please install the 'Rvmmin' package to use this optimizer."), call.=FALSE)
+   }
+
    #########################################################################
 
    if (is.element(optimizer, c("optim","constrOptim"))) {
@@ -1651,6 +1624,20 @@ tidy.rma <- function (x, ...) {
       }
    }
 
+   if (optimizer == "Rcgmin") {
+      par.arg <- "par"
+      optimizer <- "Rcgmin::Rcgmin"
+      #ctrl.arg <- ", gr='grnd', control=optcontrol"
+      ctrl.arg <- ", control=optcontrol"
+   }
+
+   if (optimizer == "Rvmmin") {
+      par.arg <- "par"
+      optimizer <- "Rvmmin::Rvmmin"
+      #ctrl.arg <- ", gr='grnd', control=optcontrol"
+      ctrl.arg <- ", control=optcontrol"
+   }
+
    if (optimizer == "optimParallel") {
       par.arg <- "par"
       optimizer <- "optimParallel::optimParallel"
@@ -1673,9 +1660,12 @@ tidy.rma <- function (x, ...) {
    ### convergence checks
 
    if (inherits(opt.res, "try-error"))
-      stop(mstyle$stop(paste0("Error during the optimization. Use verbose=TRUE and see help(", fun, ") for more details on the optimization routines.")), call.=FALSE)
+      stop(mstyle$stop(paste0("Error during the optimization. Use verbose=TRUE and see\n       help(", fun, ") for more details on the optimization routines.")), call.=FALSE)
 
-   if (is.element(optimizer, c("optim","constrOptim","nlminb","dfoptim::hjk","dfoptim::nmk","lbfgsb3c::lbfgsb3c","subplex::subplex","BB::BBoptim","Rsolnp::solnp","alabama::constrOptim.nl","optimParallel::optimParallel")) && opt.res$convergence != 0)
+   if (optimizer == "lbfgsb3c::lbfgsb3c" && is.null(opt.res$convergence)) # special provision for lbfgsb3c in case 'convergence' is missing
+      opt.res$convergence <- -99
+
+   if (is.element(optimizer, c("optim","constrOptim","nlminb","dfoptim::hjk","dfoptim::nmk","lbfgsb3c::lbfgsb3c","subplex::subplex","BB::BBoptim","Rsolnp::solnp","alabama::constrOptim.nl","Rcgmin::Rcgmin","Rvmmin:Rvmmin","optimParallel::optimParallel")) && opt.res$convergence != 0)
       stop(mstyle$stop(paste0("Optimizer (", optimizer, ") did not achieve convergence (convergence = ", opt.res$convergence, ").")), call.=FALSE)
 
    if (is.element(optimizer, c("dfoptim::mads")) && opt.res$convergence > optcontrol$tol)
@@ -1754,3 +1744,146 @@ tidy.rma <- function (x, ...) {
 }
 
 ############################################################################
+
+# theme="default" - uses the default par() of the plotting device
+# theme="light"   - forces par(fg="black",  bg="white", ...)
+# theme="dark"    - forces par(fg="gray95", bg="gray10", ...)
+# theme="auto"    - in RStudio, picks fg/bg based on theme that is set (outside RStudio, same as "default")
+# theme="custom"  - uses getmfopt("fg") and getmfopt("bg")
+
+.start.plot <- function(x=TRUE) {
+
+   if (!x)
+      return()
+
+   themeopt <- getmfopt("theme", default="default")[[1]]
+   themeopt <- sub("2", "", themeopt, fixed=TRUE)
+
+   if (!is.element(themeopt, c("default", "light", "dark", "auto", "custom")))
+      themeopt <- "default"
+
+   if (exists(".darkplots"))
+      themeopt <- "dark"
+
+   if (isTRUE(themeopt == "light")) {
+      fg <- "black"
+      bg <- "white"
+      #fg <- "gray5"
+      #bg <- "gray95"
+   }
+
+   if (isTRUE(themeopt == "dark")) {
+      fg <- "gray95"
+      bg <- "gray10"
+   }
+
+   if (isTRUE(themeopt == "auto")) {
+
+      rsapi <- try(rstudioapi::isAvailable(), silent=TRUE)
+
+      if (inherits(rsapi, "try-error") || isFALSE(rsapi)) {
+         themeopt <- "default"
+      } else {
+         fg <- .rsapicol2rgb(rstudioapi::getThemeInfo()$foreground)
+         bg <- .rsapicol2rgb(rstudioapi::getThemeInfo()$background)
+      }
+
+   }
+
+   if (isTRUE(themeopt == "custom")) {
+
+      fgopt <- getmfopt("fg")
+      bgopt <- getmfopt("bg")
+
+      if (is.null(fgopt) || is.null(bgopt)) {
+         themeopt <- "default"
+      } else {
+         fg <- fgopt
+         bg <- bgopt
+      }
+
+   }
+
+   if (themeopt != "default")
+      par(fg=fg, bg=bg, col=fg, col.axis=fg, col.lab=fg, col.main=fg, col.sub=fg)
+
+   invisible()
+
+}
+
+# convert the string "rgb(val1, val2, val3)" into rgb(val1, val2, val3, maxColorValue=255)
+
+.rsapicol2rgb <- function(col) {
+
+   col  <- strsplit(col, ",")[[1]]
+   col  <- trimws(col)
+   col1 <- as.numeric(sub("rgb(", "", col[1], fixed=TRUE))
+   col2 <- as.numeric(col[2])
+   col3 <- as.numeric(trimws(sub(")", "", col[3], fixed=TRUE)))
+   col  <- rgb(col1, col2, col3, maxColorValue=255)
+   return(col)
+
+}
+
+.is.dark <- function() {
+
+   rgb <- col2rgb(par("bg"))
+   res <- sum(rgb) <= 384 # note: sum(col2rgb(rgb(0.5,0.5,0.5))) == 384
+   return(res)
+
+}
+
+.coladj <- function(col, dark, light) {
+
+   themeopt <- getmfopt("theme", default="default")
+
+   if (length(col) == 2L && substr(themeopt, nchar(themeopt), nchar(themeopt)) == "2") {
+      pos <- 2
+      if (length(dark) == 1L)
+         dark <- c(dark, ifelse(dark > 0, dark-1, dark+1))
+      if (length(light) == 1L)
+         light <- c(light, ifelse(light > 0, light-1, light+1))
+   } else {
+      pos <- 1
+   }
+
+   col <- c(col2rgb(col[[pos]]))
+
+   if (.is.dark()) {
+      col <- col + round(dark*255)[[pos]]
+   } else {
+      col <- col + round(light*255)[[pos]]
+   }
+   col[col < 0] <- 0
+   col[col > 255] <- 255
+
+   col <- rgb(col[1], col[2], col[3], maxColorValue=255)
+   return(col)
+
+}
+
+############################################################################
+
+.chkpd <- function(x, tol=.Machine$double.eps, corr=FALSE, nearpd=FALSE) {
+
+   if (any(eigen(x, symmetric=TRUE, only.values=TRUE)$values <= tol)) {
+      ispd <- FALSE
+      if (nearpd) {
+         tmp <- nearPD(x, corr=corr)
+         x <- as.matrix(tmp$mat)
+         if (tmp$converged)
+            ispd <- TRUE
+      }
+   } else {
+      ispd <- TRUE
+   }
+
+   if (nearpd) {
+      return(list(ispd=ispd, x=x))
+   } else {
+      return(ispd)
+   }
+
+}
+
+############################################################################
