@@ -1,17 +1,26 @@
 plot.infl.rma.uni <- function(x, plotinf=TRUE, plotdfbs=FALSE, dfbsnew=FALSE, logcov=TRUE,
-layout, slab.style=1, las=0, pch=21, bg="black", bg.infl="red",
-col.na="lightgray", ...) {
+layout, slab.style=1, las=0, pch=21, bg, bg.infl, col.na, ...) {
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
-   if (!inherits(x, "infl.rma.uni"))
-      stop(mstyle$stop("Argument 'x' must be an object of class \"infl.rma.uni\"."))
+   .chkclass(class(x), must="infl.rma.uni")
 
    na.act <- getOption("na.action")
 
    if (!is.element(na.act, c("na.omit", "na.exclude", "na.fail", "na.pass")))
       stop(mstyle$stop("Unknown 'na.action' specified under options()."))
 
+   .start.plot()
+
+   if (missing(bg))
+      bg <- .coladj(par("bg","fg"), dark=0.35, light=-0.35)
+
+   if (missing(bg.infl))
+      bg.infl <- "red"
+
+   if (missing(col.na))
+      col.na <- .coladj(par("bg","fg"), dark=0.2, light=-0.2)
+
    #########################################################################
 
    ### check for NAs and stop if there are any when na.act == "na.fail"
@@ -65,7 +74,8 @@ col.na="lightgray", ...) {
    par.mar.adj <- par.mar - c(2,2,2,1)
    par.mar.adj[par.mar.adj < 1] <- 1
    par(mar = par.mar.adj)
-   on.exit(par(mar = par.mar))
+   par.mfrow <- par("mfrow")
+   on.exit(par(mar = par.mar, mfrow = par.mfrow), add=TRUE)
 
    #########################################################################
 
@@ -91,9 +101,6 @@ col.na="lightgray", ...) {
       ### set layout (either defaults or user-specified)
       ### note: could also use n2mfrow() here, but this behaves slightly differently
 
-      par.mfrow <- par("mfrow")
-      on.exit(par(mfrow = par.mfrow), add=TRUE)
-
       if (missing(layout)) {
 
          if (length(which.inf) == 2L)
@@ -127,7 +134,7 @@ col.na="lightgray", ...) {
 
       ######################################################################
 
-      for (i in seq_len(length(which.inf))) {
+      for (i in seq_along(which.inf)) {
 
          if (which.inf[i] == 1) {
 
@@ -146,8 +153,8 @@ col.na="lightgray", ...) {
                lab.ids  <- ids
             }
             if (any(!is.na(zi))) {
-               zi.min <- min(zi,-2,na.rm=TRUE)
-               zi.max <- max(zi, 2,na.rm=TRUE)
+               zi.min <- min(min(zi,-2,na.rm=TRUE), qnorm(.025))*1.05
+               zi.max <- max(max(zi, 2,na.rm=TRUE), qnorm(.975))*1.05
                lplot(NA, NA, xlim=c(1,len.ids), ylim=c(zi.min,zi.max), xaxt="n", main="rstudent", xlab="", ylab="", las=las, ...)
                laxis(side=1, at=seq_len(len.ids), labels=lab.ids, xlab="", las=las, ...)
                labline(h=0, lty="dashed", ...)
@@ -155,8 +162,8 @@ col.na="lightgray", ...) {
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
                #if (num.infl)
                #   text(seq_len(len.ids)[ids.infl], zi[ids.infl], seq_len(len.ids)[ids.infl], pos=ifelse(zi[ids.infl] > 0, 3, 1), ...)
             } else {
@@ -182,8 +189,8 @@ col.na="lightgray", ...) {
                lab.ids  <- ids
             }
             if (any(!is.na(zi))) {
-               zi.min <- min(zi,na.rm=TRUE)
-               zi.max <- max(zi,na.rm=TRUE)
+               zi.min <- min(min(zi,na.rm=TRUE), -3*sqrt(x$p/(x$k-x$p)))*1.05
+               zi.max <- max(max(zi,na.rm=TRUE),  3*sqrt(x$p/(x$k-x$p)))*1.05
                lplot(NA, NA, xlim=c(1,len.ids), ylim=c(zi.min,zi.max), xaxt="n", main="dffits", xlab="", ylab="", las=las, ...)
                laxis(side=1, at=seq_len(len.ids), labels=lab.ids, xlab="", las=las, ...)
                labline(h= 0, lty="dashed", ...)
@@ -192,8 +199,8 @@ col.na="lightgray", ...) {
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
                #if (num.infl)
                #   text(seq_len(len.ids)[ids.infl], zi[ids.infl], seq_len(len.ids)[ids.infl], pos=ifelse(zi[ids.infl] > 0, 3, 1), ...)
             } else {
@@ -219,16 +226,16 @@ col.na="lightgray", ...) {
                lab.ids  <- ids
             }
             if (any(!is.na(zi))) {
-               zi.min <- min(zi,na.rm=TRUE)
-               zi.max <- max(zi,na.rm=TRUE)
+               zi.min <- 0
+               zi.max <- max(zi,na.rm=TRUE)*1.05
                lplot(NA, NA, xlim=c(1,len.ids), ylim=c(zi.min,zi.max), xaxt="n", main="cook.d", xlab="", ylab="", las=las, ...)
                laxis(side=1, at=seq_len(len.ids), labels=lab.ids, xlab="", las=las, ...)
                labline(h=qchisq(0.5, df=x$m), lty="dotted", ...)
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
                #if (num.infl)
                #   text(seq_len(len.ids)[ids.infl], zi[ids.infl], seq_len(len.ids)[ids.infl], pos=3, ...)
             } else {
@@ -268,8 +275,8 @@ col.na="lightgray", ...) {
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
                #if (num.infl)
                #   text(seq_len(len.ids)[ids.infl], zi[ids.infl], seq_len(len.ids)[ids.infl], pos=ifelse(zi[ids.infl] > 1, 3, 1), ...)
             } else {
@@ -303,8 +310,8 @@ col.na="lightgray", ...) {
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
             } else {
                lplot(NA, NA, xlim=c(0,1), ylim=c(0,1), xaxt="n", yaxt="n", main="tau2.del", xlab="", ylab="", ...)
             }
@@ -337,8 +344,8 @@ col.na="lightgray", ...) {
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
             } else {
                lplot(NA, NA, xlim=c(0,1), ylim=c(0,1), xaxt="n", yaxt="n", main="QE.del", xlab="", ylab="", ...)
             }
@@ -363,7 +370,7 @@ col.na="lightgray", ...) {
             }
             if (any(!is.na(zi))) {
                zi.min <- 0
-               zi.max <- max(zi,na.rm=TRUE)
+               zi.max <- max(max(zi,na.rm=TRUE), 3*x$p/x$k)*1.05
                lplot(NA, NA, xlim=c(1,len.ids), ylim=c(zi.min,zi.max), xaxt="n", main="hat", xlab="", ylab="", las=las, ...)
                laxis(side=1, at=seq_len(len.ids), labels=lab.ids, xlab="", las=las, ...)
                labline(h=x$p/x$k, lty="dashed", ...)
@@ -371,8 +378,8 @@ col.na="lightgray", ...) {
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
             } else {
                lplot(NA, NA, xlim=c(0,1), ylim=c(0,1), xaxt="n", yaxt="n", main="hat", xlab="", ylab="", ...)
             }
@@ -397,15 +404,15 @@ col.na="lightgray", ...) {
             }
             if (any(!is.na(zi))) {
                zi.min <- 0
-               zi.max <- max(zi,na.rm=TRUE)
+               zi.max <- max(zi,na.rm=TRUE)*1.05
                lplot(NA, NA, xlim=c(1,len.ids), ylim=c(zi.min,zi.max), xaxt="n", main="weight", xlab="", ylab="", las=las, ...)
                laxis(side=1, at=seq_len(len.ids), labels=lab.ids, xlab="", las=las, ...)
                labline(h=100/x$k, lty="dashed", ...)
                if (na.act == "na.exclude" || na.act == "na.pass")
                   llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
                llines(seq_len(len.ids), zi, ...)
-               lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-               lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+               lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+               lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
             } else {
                lplot(NA, NA, xlim=c(0,1), ylim=c(0,1), xaxt="n", yaxt="n", main="weight", xlab="", ylab="", ...)
             }
@@ -437,9 +444,9 @@ col.na="lightgray", ...) {
          }
       }
 
-      par(mfrow=c(length(which.dfbs),1))
+      par(mfrow=n2mfrow(length(which.dfbs)))
 
-      for (i in seq_len(length(which.dfbs))) {
+      for (i in seq_along(which.dfbs)) {
 
          zi     <- x$dfbs[[which.dfbs[i]]]
          not.na <- !is.na(zi)
@@ -455,7 +462,9 @@ col.na="lightgray", ...) {
             ids.infl <- x$is.infl
             lab.ids  <- ids
          }
-         lplot(NA, NA, xlim=c(1,len.ids), ylim=range(zi,na.rm=TRUE), xaxt="n", main=paste("dfbs: ", names(x$dfbs)[which.dfbs[i]]), xlab="", ylab="", las=las, ...)
+         zi.min <- min(zi,na.rm=TRUE)*1.05
+         zi.max <- max(zi,na.rm=TRUE)*1.05
+         lplot(NA, NA, xlim=c(1,len.ids), ylim=c(zi.min,zi.max), xaxt="n", main=paste("dfbs: ", names(x$dfbs)[which.dfbs[i]]), xlab="", ylab="", las=las, ...)
          laxis(side=1, at=seq_len(len.ids), labels=lab.ids, xlab="", las=las, ...)
          labline(h= 0, lty="dashed", ...)
          labline(h= 1, lty="dotted", ...)
@@ -463,8 +472,8 @@ col.na="lightgray", ...) {
          if (na.act == "na.exclude" || na.act == "na.pass")
             llines(seq_len(len.ids)[not.na], zi[not.na], col=col.na, ...)
          llines(seq_len(len.ids), zi, ...)
-         lpoints(seq_len(len.ids), zi, pch=pch, bg=bg, ...)
-         lpoints(seq_len(len.ids)[ids.infl], zi[ids.infl], bg=bg.infl, pch=pch, ...)
+         lpoints(x=seq_len(len.ids),           y=zi,           bg=bg,      pch=pch, ...)
+         lpoints(x=seq_len(len.ids)[ids.infl], y=zi[ids.infl], bg=bg.infl, pch=pch, ...)
 
       }
 
