@@ -11,13 +11,13 @@ print.list.anova.rma <- function(x, digits=x[[1]]$digits, ...) {
    res.table <- as.data.frame(x)
 
    if ("QM" %in% names(res.table))
-      res.table$QM <- .fcf(res.table$QM, digits[["test"]])
+      res.table$QM <- fmtx(res.table$QM, digits[["test"]])
    if ("QS" %in% names(res.table))
-      res.table$QS <- .fcf(res.table$QS, digits[["test"]])
+      res.table$QS <- fmtx(res.table$QS, digits[["test"]])
    if ("Fval" %in% names(res.table))
-      res.table$Fval <- .fcf(res.table$Fval, digits[["test"]])
+      res.table$Fval <- fmtx(res.table$Fval, digits[["test"]])
 
-   res.table$pval <- .pval(res.table$pval, digits[["pval"]])
+   res.table$pval <- fmtp(res.table$pval, digits[["pval"]])
 
    tmp <- capture.output(print(res.table, quote=FALSE, right=TRUE))
    .print.table(tmp, mstyle)
