@@ -14,7 +14,7 @@ print.list.confint.rma <- function(x, digits=x$digits, ...) {
 
    for (j in seq_len(len)) {
 
-      res.random <- .fcf(x[[j]]$random, digits[["var"]])
+      res.random <- fmtx(x[[j]]$random, digits[["var"]])
       res.random[,2] <- paste0(x[[j]]$lb.sign, res.random[,2])
       res.random[,3] <- paste0(x[[j]]$ub.sign, res.random[,3])
       tmp <- capture.output(print(res.random, quote=FALSE, right=TRUE))
