@@ -68,7 +68,7 @@ profile.rma.ls <- function(fitted, alpha,
 
       if (plot) {
          if (dev.cur() == 1) {
-            par(mfrow=c(comps, 1))
+            par(mfrow=n2mfrow(comps))
             #on.exit(par(mfrow=c(1,1)), add=TRUE)
          }
       }
@@ -133,7 +133,7 @@ profile.rma.ls <- function(fitted, alpha,
 
    ### if everything is good so far, get value of the component and set 'comp'
 
-   alpha.pos <- NA
+   alpha.pos <- NA_integer_
 
    if (!missing(alpha)) {
       vc <- x$alpha[alpha]
@@ -233,17 +233,16 @@ profile.rma.ls <- function(fitted, alpha,
 
    if (missing(ylim)) {
 
-      if (any(!is.na(lls))) {
+      if (any(is.finite(lls))) {
          if (xlim[1] <= vc && xlim[2] >= vc) {
-            ylim <- range(c(logLik(x),lls), na.rm=TRUE)
+            ylim <- range(c(logLik(x),lls[is.finite(lls)]), na.rm=TRUE)
          } else {
-            ylim <- range(lls, na.rm=TRUE)
+            ylim <- range(lls[is.finite(lls)])
          }
       } else {
          ylim <- rep(logLik(x), 2L)
       }
-      ylim[1] <- ylim[1] - .1
-      ylim[2] <- ylim[2] + .1
+      ylim <- ylim + c(-0.1, 0.1)
 
    } else {
 
