@@ -61,8 +61,8 @@ profile.rma.uni <- function(fitted,
 
       if (inherits(vc.ci, "try-error")) {
 
-         vc.lb <- NA
-         vc.ub <- NA
+         vc.lb <- NA_real_
+         vc.ub <- NA_real_
 
       } else {
 
@@ -160,17 +160,16 @@ profile.rma.uni <- function(fitted,
 
    if (missing(ylim)) {
 
-      if (any(!is.na(lls))) {
+      if (any(is.finite(lls))) {
          if (xlim[1] <= x$tau2 && xlim[2] >= x$tau2) {
-            ylim <- range(c(logLik(x),lls), na.rm=TRUE)
+            ylim <- range(c(logLik(x),lls[is.finite(lls)]), na.rm=TRUE)
          } else {
-            ylim <- range(lls, na.rm=TRUE)
+            ylim <- range(lls[is.finite(lls)])
          }
       } else {
          ylim <- rep(logLik(x), 2L)
       }
-      ylim[1] <- ylim[1] - .1
-      ylim[2] <- ylim[2] + .1
+      ylim <- ylim + c(-0.1, 0.1)
 
    } else {
 
