@@ -32,6 +32,8 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
    if (is.function(transf) && is.function(atransf))
       stop(mstyle$stop("Use either 'transf' or 'atransf' to specify a transformation (not both)."))
 
+   .start.plot()
+
    mf <- match.call()
 
    if (missing(pch)) {
@@ -47,13 +49,13 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
    }
 
    if (missing(col)) {
-      col <- "black"
+      col <- par("fg")
    } else {
       col <- .getx("col", mf=mf, data=x$data)
    }
 
    if (missing(bg)) {
-      bg <- "darkgray"
+      bg <- .coladj(par("bg","fg"), dark=0.35, light=-0.35)
    } else {
       bg <- .getx("bg", mf=mf, data=x$data)
    }
@@ -85,16 +87,19 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
    ### grid argument can either be a logical or a color
 
    if (is.logical(grid))
-      gridcol <- "gray"
+      gridcol <- .coladj(par("bg","fg"), dark=c(0.2,-0.6), light=c(-0.2,0.6))
+
    if (is.character(grid)) {
       gridcol <- grid
       grid <- TRUE
    }
 
-   ### shade argument can either be a logical or a color
+   ### shade argument can either be a logical or a color (first for ci, second for pi)
+
+   if (is.logical(shade)) {
+      shadecol <- c(.coladj(par("bg","fg"), dark=0.15, light=-0.15), .coladj(par("bg","fg"), dark=0.05, light=-0.05))
+   }
 
-   if (is.logical(shade))
-      shadecol <- c("gray85", "gray95") # first for ci, second for pi
    if (is.character(shade)) {
       if (length(shade) == 1L)
          shade <- c(shade, shade)
@@ -117,19 +122,19 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
    ### set refline to NA if it is not specified
 
    if (missing(refline))
-      refline <- NA
+      refline <- NA_real_
 
    ### set lcol, lty, and lwd (1 = reg line, 2 = ci bounds, 3 = pi bounds, 4 = refline)
 
    if (missing(lcol)) {
-      lcol <- c("black", "black", "black", "gray40")
+      lcol <- c(rep(par("fg"), 3), .coladj(par("bg","fg"), dark=0.5, light=-0.5))
    } else {
       if (length(lcol) == 1L)
          lcol <- rep(lcol, 4L)
       if (length(lcol) == 2L)
-         lcol <- c(lcol[c(1,2,2)], "gray40")
+         lcol <- c(lcol[c(1,2,2)], .coladj(par("bg","fg"), dark=0.5, light=-0.5))
       if (length(lcol) == 3L)
-         lcol <- c(lcol, "gray40")
+         lcol <- c(lcol, .coladj(par("bg","fg"), dark=0.5, light=-0.5))
    }
 
    if (missing(lty)) {
@@ -158,14 +163,14 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
 
    ddd <- list(...)
 
-   lplot    <- function(..., grep, fixed) plot(...)
-   laxis    <- function(..., grep, fixed) axis(...)
-   lpolygon <- function(..., grep, fixed) polygon(...)
-   llines   <- function(..., grep, fixed) lines(...)
-   lpoints  <- function(..., grep, fixed) points(...)
-   labline  <- function(..., grep, fixed) abline(...)
-   lbox     <- function(..., grep, fixed) box(...)
-   ltext    <- function(..., grep, fixed) text(...)
+   lplot    <- function(..., grep, fixed, box.lty) plot(...)
+   laxis    <- function(..., grep, fixed, box.lty) axis(...)
+   lpolygon <- function(..., grep, fixed, box.lty) polygon(...)
+   llines   <- function(..., grep, fixed, box.lty) lines(...)
+   lpoints  <- function(..., grep, fixed, box.lty) points(...)
+   labline  <- function(..., grep, fixed, box.lty) abline(...)
+   lbox     <- function(..., grep, fixed, box.lty) box(...)
+   ltext    <- function(..., grep, fixed, box.lty) text(...)
 
    if (is.null(ddd$fixed)) {
       fixed <- FALSE
@@ -179,6 +184,12 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
       grep <- .isTRUE(ddd$grep)
    }
 
+   if (is.null(ddd$box.lty)) {
+      box.lty <- par("lty")
+   } else {
+      box.lty <- ddd$box.lty
+   }
+
    ############################################################################
 
    ### checks on mod argument
@@ -618,12 +629,12 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
 
    if (is.function(atransf)) {
       if (is.null(targs)) {
-         at.lab <- formatC(sapply(at.lab, atransf), digits=digits[[1]], format="f", drop0trailing=is.integer(digits[[1]]))
+         at.lab <- fmtx(sapply(at.lab, atransf), digits[[1]], drop0ifint=TRUE)
       } else {
-         at.lab <- formatC(sapply(at.lab, atransf, targs), digits=digits[[1]], format="f", drop0trailing=is.integer(digits[[1]]))
+         at.lab <- fmtx(sapply(at.lab, atransf, targs), digits[[1]], drop0ifint=TRUE)
       }
    } else {
-      at.lab <- formatC(at.lab, digits=digits[[1]], format="f", drop0trailing=is.integer(digits[[1]]))
+      at.lab <- fmtx(at.lab, digits[[1]], drop0ifint=TRUE)
    }
 
    ### add y-axis
@@ -745,7 +756,7 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- NA
          lty.l  <- "blank"
          lwd.l  <- NA
-         tcol.l <- "white"
+         tcol.l <- "transparent"
          ltxt   <- "Studies"
       }
 
@@ -755,7 +766,7 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- c(bg.l,  NA)
          lty.l  <- c(lty.l, NA)
          lwd.l  <- c(lwd.l, NA)
-         tcol.l <- c(tcol.l, "white")
+         tcol.l <- c(tcol.l, "transparent")
          ltxt   <- c(ltxt, "Regression Line")
       }
 
@@ -765,7 +776,7 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- c(bg.l,  shadecol[1])
          lty.l  <- c(lty.l, NA)
          lwd.l  <- c(lwd.l, 1)
-         tcol.l <- c(tcol.l, "white")
+         tcol.l <- c(tcol.l, "transparent")
          ltxt   <- c(ltxt, paste0(round(100*(1-level), digits[[1]]), "% Confidence Interval"))
       }
 
@@ -775,12 +786,12 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- c(bg.l,  shadecol[2])
          lty.l  <- c(lty.l, NA)
          lwd.l  <- c(lwd.l, 1)
-         tcol.l <- c(tcol.l, "white")
+         tcol.l <- c(tcol.l, "transparent")
          ltxt   <- c(ltxt, paste0(round(100*(1-level), digits[[1]]), "% Prediction Interval"))
       }
 
       if (length(ltxt) >= 1L)
-         legend(lpos, inset=.01, bg="white", pch=pch.l, col=col.l, pt.bg=bg.l, lty=lty.l, lwd=lwd.l, text.col=tcol.l, pt.cex=1.5, seg.len=3, legend=ltxt)
+         legend(lpos, inset=.01, bg=par("bg"), pch=pch.l, col=col.l, pt.bg=bg.l, lty=lty.l, lwd=lwd.l, text.col=tcol.l, pt.cex=1.5, seg.len=3, legend=ltxt, box.lty=box.lty)
 
       pch.l  <- NULL
       col.l  <- NULL
@@ -796,7 +807,7 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- bg[1]
          lty.l  <- "blank"
          lwd.l  <- 1
-         tcol.l <- "black"
+         tcol.l <- par("fg")
          ltxt   <- "Studies"
       }
 
@@ -806,7 +817,7 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- c(bg.l,  NA)
          lty.l  <- c(lty.l, lty[1])
          lwd.l  <- c(lwd.l, lwd[1])
-         tcol.l <- c(tcol.l, "black")
+         tcol.l <- c(tcol.l, par("fg"))
          ltxt   <- c(ltxt, "Regression Line")
       }
 
@@ -816,7 +827,7 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- c(bg.l,  NA)
          lty.l  <- c(lty.l, lty[2])
          lwd.l  <- c(lwd.l, lwd[2])
-         tcol.l <- c(tcol.l, "black")
+         tcol.l <- c(tcol.l, par("fg"))
          ltxt   <- c(ltxt, paste0(round(100*(1-level), digits[[1]]), "% Confidence Interval"))
       }
 
@@ -826,12 +837,12 @@ lcol, lwd, lty, legend=FALSE, xvals, ...) {
          bg.l   <- c(bg.l,  NA)
          lty.l  <- c(lty.l, lty[3])
          lwd.l  <- c(lwd.l, lwd[3])
-         tcol.l <- c(tcol.l, "black")
+         tcol.l <- c(tcol.l, par("fg"))
          ltxt   <- c(ltxt, paste0(round(100*(1-level), digits[[1]]), "% Prediction Interval"))
       }
 
       if (length(ltxt) >= 1L)
-         legend(lpos, inset=.01, bg=NA, pch=pch.l, col=col.l, pt.bg=bg.l, lty=lty.l, lwd=lwd.l, text.col=tcol.l, pt.cex=1.5, seg.len=3, legend=ltxt)
+         legend(lpos, inset=.01, bg=NA, pch=pch.l, col=col.l, pt.bg=bg.l, lty=lty.l, lwd=lwd.l, text.col=tcol.l, pt.cex=1.5, seg.len=3, legend=ltxt, box.lty=box.lty)
 
    }
 
