@@ -1,4 +1,4 @@
-rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TRUE, parallel="no", ncpus=1, cl=NULL, ...) {
+rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TRUE, parallel="no", ncpus=1, cl, ...) {
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
@@ -16,6 +16,9 @@ rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TR
    if (parallel == "no" && ncpus > 1)
       parallel <- "snow"
 
+   if (missing(cl))
+      cl <- NULL
+
    if (!is.null(cl) && inherits(cl, "SOCKcluster")) {
       parallel <- "snow"
       ncpus <- length(cl)
@@ -38,7 +41,7 @@ rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TR
 
    if (!progbar) {
       pbo <- pbapply::pboptions(type="none")
-      on.exit(pbapply::pboptions(pbo))
+      on.exit(pbapply::pboptions(pbo), add=TRUE)
    }
 
    if (missing(digits)) {
@@ -49,8 +52,12 @@ rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TR
 
    misscluster <- ifelse(missing(cluster), TRUE, FALSE)
 
-   if (misscluster)
+   if (misscluster) {
       cluster <- seq_len(x$k.all)
+   } else {
+      mf <- match.call()
+      cluster <- .getx("cluster", mf=mf, data=x$data)
+   }
 
    ddd <- list(...)
 
@@ -68,8 +75,10 @@ rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TR
    # the same subsetting and removing of missings (if necessary) as was done
    # during model fitting
 
-   if (!is.null(x$subset))
-      cluster <- cluster[x$subset]
+   if (length(cluster) != x$k.all)
+      stop(mstyle$stop(paste0("Length of variable specified via 'cluster' (", length(cluster), ") does not match length of data (", x$k.all, ").")))
+
+   cluster <- .getsubset(cluster, x$subset)
 
    cluster.f <- cluster
 
@@ -83,9 +92,6 @@ rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TR
    if (length(cluster.f) == 0L)
       stop(mstyle$stop(paste0("Cannot find 'cluster' variable (or it has zero length).")))
 
-   if (length(cluster) != x$k)
-      stop(mstyle$stop(paste0("Length of variable specified via 'cluster' (", length(cluster), ") does not match length of data (", x$k, ").")))
-
    ### cluster ids and number of clusters
 
    ids <- unique(cluster)
@@ -199,6 +205,7 @@ rstudent.rma.mv <- function(model, digits, progbar=FALSE, cluster, reestimate=TR
       class(out[[2]]) <- "list.rma"
       attr(out[[1]], ".rmspace") <- TRUE
       attr(out[[2]], ".rmspace") <- TRUE
+
       return(out)
 
    }
