@@ -24,7 +24,7 @@ addid=TRUE, addcomp=TRUE, adddesign=TRUE, minlen=2, var.names=c("id","comp","des
 
    if (any(var.names != make.names(var.names, unique=TRUE))) {
       var.names <- make.names(var.names, unique=TRUE)
-      warning(mstyle$warning(paste0("Argument 'var.names' does not contain syntactically valid variable names.\nVariable names adjusted to: var.names = c('", var.names[1], "', '", var.names[2], "', '", var.names[3], "').")), call.=FALSE)
+      warning(mstyle$warning(paste0("Argument 'var.names' does not contain syntactically valid variable names.\nVariable names adjusted to: var.names = c('", var.names[1], "','", var.names[2], "','", var.names[3], "').")), call.=FALSE)
    }
 
    ############################################################################
@@ -164,7 +164,7 @@ addid=TRUE, addcomp=TRUE, adddesign=TRUE, minlen=2, var.names=c("id","comp","des
 
    ### and make sure that grp.pos is always in the first position of grpvars.pos
 
-   grpvars.pos <- unique(c(grp.pos, grpvars.pos))
+   grpvars.pos <- union(grp.pos, grpvars.pos)
 
    ############################################################################
 
