@@ -27,7 +27,7 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
    ### determine side (if none is specified)
 
    if (is.null(side)) {
-      args <- list(yi=yi, vi=vi, weights=wi, mods=sqrt(vi), method=x$method, weighted=x$weighted, outlist="beta=beta", ...)
+      args <- list(yi=yi, vi=vi, weights=wi, mods=sqrt(vi), method=x$method, weighted=x$weighted, control=x$control, outlist="beta=beta", ...)
       res <- suppressWarnings(.do.call(rma.uni, args))
       ### TODO: add check in case there are problems with fitting the model
       if (res$beta[2] < 0) {
@@ -78,7 +78,7 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
       vi.t <- vi[seq_len(k-k0)]
       wi.t <- wi[seq_len(k-k0)]
 
-      args <- list(yi=yi.t, vi=vi.t, weights=wi.t, method=x$method, weighted=x$weighted, outlist="beta=beta", ...)
+      args <- list(yi=yi.t, vi=vi.t, weights=wi.t, method=x$method, weighted=x$weighted, control=x$control, outlist="beta=beta", ...)
       res <- suppressWarnings(.do.call(rma.uni, args))
 
       ### intercept estimate based on truncated data
@@ -120,9 +120,9 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
       se.k0 <- max(0, se.k0)
 
       if (verbose)
-         cat(mstyle$verbose(paste0("Iteration: ", formatC(iter, format="f", digits=0, width=nchar(maxiter), flag="-"),
-                                   "  missing = ", formatC(k0, format="f", digits=0, width=nchar(k), flag="-"),
-                                   "  beta = ",    formatC(ifelse(side == "right", -1*beta, beta), format="f", digits=x$digits[["est"]]), "\n")))
+         cat(mstyle$verbose(paste0("Iteration: ",  fmtx(iter, 0, addwidth=nchar(maxiter), flag="-"),
+                                   "  missing = ", fmtx(k0,   0, addwidth=nchar(k), flag="-"),
+                                   "  beta = ",    fmtx(ifelse(side == "right", -1*beta, beta), x$digits[["est"]]), "\n")))
 
    }
 
@@ -198,7 +198,7 @@ trimfill.rma.uni <- function(x, side, estimator="L0", maxiter=100, verbose=FALSE
       m <- -1:(k0-1)
       res$p.k0 <- 1 - sum(choose(0+m+1, m+1) * 0.5^(0+m+2))
    } else {
-      res$p.k0 <- NA
+      res$p.k0 <- NA_real_
    }
 
    class(res) <- c("rma.uni.trimfill", class(res))
