@@ -1,5 +1,5 @@
 vcalc <- function(vi, cluster, subgroup, obs, type, time1, time2, grp1, grp2, w1, w2,
-data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
+data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, sparse=FALSE, ...) {
 
    mstyle <- .get.mstyle("crayon" %in% .packages())
 
@@ -54,10 +54,10 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
    obs      <- .getx("obs",      mf=mf, data=data)
    grp1     <- .getx("grp1",     mf=mf, data=data)
    grp2     <- .getx("grp2",     mf=mf, data=data)
-   time1    <- .getx("time1",    mf=mf, data=data)
-   time2    <- .getx("time2",    mf=mf, data=data)
-   w1       <- .getx("w1",       mf=mf, data=data)
-   w2       <- .getx("w2",       mf=mf, data=data)
+   time1    <- .getx("time1",    mf=mf, data=data, checknumeric=TRUE)
+   time2    <- .getx("time2",    mf=mf, data=data, checknumeric=TRUE)
+   w1       <- .getx("w1",       mf=mf, data=data, checknumeric=TRUE)
+   w2       <- .getx("w2",       mf=mf, data=data, checknumeric=TRUE)
 
    ############################################################################
 
@@ -69,7 +69,7 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
    k <- length(vi)
 
    if (k == 1L)
-      stop(mstyle$stop("Processing terminated since k = 1."))
+      stop(mstyle$stop("Processing terminated since k = 1.")) # could also do: return(matrix(vi, nrow=1, ncol=1))
 
    #########################################################################
 
@@ -333,9 +333,19 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
 
       ############################################################################
 
+      #### turn obs and type into character variables to that [obs[i],obs[j]] and [type[i],type[j]] below work correctly
+
+      obs  <- as.character(obs)
+      type <- as.character(type)
+
       ### construct R matrix
 
-      R <- matrix(0, nrow=k, ncol=k)
+      if (sparse) {
+         R <- Matrix(0, nrow=k, ncol=k)
+      } else {
+         R <- matrix(0, nrow=k, ncol=k)
+      }
+
       diag(R) <- 1
 
       for (i in 2:k) {
@@ -409,6 +419,9 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
 
       R <- bldiag(R, order=cluster)
 
+      if (sparse)
+         R <- Matrix(R, sparse=TRUE)
+
    }
 
    #return(R)
@@ -423,14 +436,14 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
 
          Ri <- R[cluster == ucluster[i], cluster == ucluster[i]]
 
-         if (!anyNA(Ri) && any(eigen(Ri, symmetric=TRUE, only.values=TRUE)$values <= .Machine$double.eps)) {
+         if (!anyNA(Ri) && !.chkpd(Ri)) {
 
             if (nearpd) {
                Ri <- try(as.matrix(nearPD(Ri, corr=TRUE)$mat), silent=TRUE)
                if (inherits(Ri, "try-error")) {
                   warning(mstyle$warning(paste0("Using nearPD() failed in cluster ", ucluster[i], ".")), call.=FALSE)
                } else {
-                  if (!anyNA(Ri) && any(eigen(Ri, symmetric=TRUE, only.values=TRUE)$values <= .Machine$double.eps))
+                  if (!anyNA(Ri) && !.chkpd(Ri))
                      warning(mstyle$warning(paste0("The var-cov matrix still appears to be not positive definite in cluster ", ucluster[i], " even after nearPD().")), call.=FALSE)
                   R[cluster == ucluster[i], cluster == ucluster[i]] <- Ri
                }
@@ -448,7 +461,12 @@ data, rho, phi, rvars, checkpd=TRUE, nearpd=FALSE, ...) {
 
    ### turn R into V
 
-   S <- diag(sqrt(as.vector(vi)), nrow=k, ncol=k)
+   if (sparse) {
+      S <- Diagonal(k, sqrt(as.vector(vi)))
+   } else {
+      S <- diag(sqrt(as.vector(vi)), nrow=k, ncol=k)
+   }
+
    V <- S %*% R %*% S
 
    if (.isTRUE(ddd$retdat))
