@@ -1,27 +1,56 @@
 .onAttach <- function(libname, pkgname) {
 
-   ver <- "3.8-1"
+   ver <- "4.4-0"
 
    loadmsg <- paste0("\nLoading the 'metafor' package (version ", ver, "). For an\nintroduction to the package please type: help(metafor)\n")
 
    installed.ver <- as.numeric(strsplit(gsub("-", ".", ver, fixed=TRUE), ".", fixed=TRUE)[[1]])
 
+   # set default options
+
+   mfopts <- getOption("metafor")
+
+   if (is.null(mfopts) || !is.list(mfopts)) {
+      options("metafor" = list(check=TRUE, silent=FALSE, space=TRUE, theme="default"))
+   } else {
+      if (is.null(mfopts$check))
+         mfopts$check <- TRUE
+      if (is.null(mfopts$silent))
+         mfopts$silent <- FALSE
+      if (is.null(mfopts$space))
+         mfopts$space <- TRUE
+      if (is.null(mfopts$theme))
+         mfopts$theme <- "default"
+      options("metafor" = mfopts)
+   }
+
    # only run version check in an interactive session and if METAFOR_VERSION_CHECK is not FALSE
 
-   verchk <- tolower(Sys.getenv("METAFOR_VERSION_CHECK"))
+   verchk <- tolower(Sys.getenv("METAFOR_VERSION_CHECK")) # "" if unset
+
+   checkopt <- getOption("metafor")$check
+
+   if (!is.null(checkopt)) {
+      if (is.logical(checkopt) && isFALSE(checkopt))
+         verchk <- "false"
+      if (is.character(checkopt) && isTRUE(checkopt == "devel"))
+         verchk <- "devel"
+   }
 
    if (interactive() && verchk != "false") {
 
-      if (verchk  == "devel") {
+      #print("Version check ...")
+
+      if (isTRUE(verchk == "devel")) {
 
          # pull version number from GitHub
 
          tmp <- suppressWarnings(try(readLines("https://raw.githubusercontent.com/wviechtb/metafor/master/DESCRIPTION", n=2), silent=TRUE))
 
-         if (!inherits(tmp, "try-error")) {
+         if (!inherits(tmp, "try-error") && length(tmp) == 2L) {
             available.ver <- tmp[2]
             if (!is.na(available.ver) && length(available.ver) != 0L)
-               available.ver <- substr(available.ver, 10, nchar(available.ver))
+               available.ver <- substr(available.ver, 10, nchar(available.ver)) # strip 'Version: ' part
          }
 
       } else {
@@ -44,11 +73,11 @@
          installed.ver <- 100000 * installed.ver[1] + 1000 * installed.ver[2] + installed.ver[3]
          available.ver <- 100000 * available.ver[1] + 1000 * available.ver[2] + available.ver[3]
          if (isTRUE(installed.ver < available.ver)) {
-            paste0(loadmsg, "\nAn updated version of the package (version ", save.ver, ") is available!\nTo update to this version type: ")
-            if (verchk  == "devel") {
-               loadmsg <- paste0(loadmsg, "install.packages(\"metafor\")\n")
-            } else {
+            loadmsg <- paste0(loadmsg, "\nAn updated version of the package (version ", save.ver, ") is available!\nTo update to this version type: ")
+            if (isTRUE(verchk == "devel")) {
                loadmsg <- paste0(loadmsg, "remotes::install_github(\"wviechtb/metafor\")\n")
+            } else {
+               loadmsg <- paste0(loadmsg, "install.packages(\"metafor\")\n")
             }
          }
       }
@@ -68,7 +97,8 @@
       min_time = 2,
       use_lb = FALSE))
 
-   packageStartupMessage(loadmsg, domain=NULL, appendLF=TRUE)
+   if (isFALSE(getOption("metafor")$silent))
+      packageStartupMessage(loadmsg, domain=NULL, appendLF=TRUE)
 
 }
 
