@@ -2,7 +2,7 @@
 
 context("Checking misc: regtest() and ranktest() functions")
 
-source("tolerances.r") # read in tolerances
+source("settings.r")
 
 test_that("regtest() works correctly for 'rma.uni' objects.", {
 
@@ -14,13 +14,19 @@ test_that("regtest() works correctly for 'rma.uni' objects.", {
 
    out <- capture.output(print(sav)) ### so that print.regtest.rma() is run (at least once)
 
-   sav <- regtest(dat$yi, dat$vi)
+   sav <- regtest(yi, vi, data=dat)
+   expect_equivalent(sav$zval, -4.6686, tolerance=.tol[["test"]])
+
+   sav <- regtest(yi, vi, data=dat)
    expect_equivalent(sav$zval, -4.6686, tolerance=.tol[["test"]])
 
    sav <- regtest(res, model="lm", predictor="sqrtninv")
    expect_equivalent(sav$zval, -5.6083, tolerance=.tol[["test"]])
 
-   sav <- regtest(dat$yi, dat$vi, model="lm", predictor="sqrtninv")
+   sav <- regtest(yi, vi, data=dat, model="lm", predictor="sqrtninv")
+   expect_equivalent(sav$zval, -5.6083, tolerance=.tol[["test"]])
+
+   sav <- regtest(yi, vi, data=dat, model="lm", predictor="sqrtninv")
    expect_equivalent(sav$zval, -5.6083, tolerance=.tol[["test"]])
 
 })
@@ -34,10 +40,16 @@ test_that("ranktest() works correctly for 'rma.uni' objects.", {
    expect_equivalent(sav$tau, 0.15)
    expect_equivalent(sav$pval, 0.4503, tolerance=.tol[["pval"]])
 
-   sav <- ranktest(dat$yi, dat$vi)
+   sav <- ranktest(yi, vi, data=dat)
+   expect_equivalent(sav$tau, 0.15)
+   expect_equivalent(sav$pval, 0.4503, tolerance=.tol[["pval"]])
+
+   sav <- ranktest(yi, vi, data=dat)
    expect_equivalent(sav$tau, 0.15)
    expect_equivalent(sav$pval, 0.4503, tolerance=.tol[["pval"]])
 
    out <- capture.output(print(sav)) ### so that print.ranktest.rma() is run (at least once)
 
 })
+
+rm(list=ls())
