@@ -22,9 +22,11 @@ test_that("results are correct for a step function model.", {
    expect_identical(sav$LRTdf, 3L)
    expect_equivalent(sav$tau2, 0.03071325, tolerance=.tol[["var"]])
 
-   opar <- par(no.readonly=TRUE)
+   png(filename="images/test_misc_selmodel_1_test.png", res=200, width=1800, height=1600, type="cairo")
    plot(sav)
-   par(opar)
+   dev.off()
+
+   expect_true(.vistest("images/test_misc_selmodel_1_test.png", "images/test_misc_selmodel_1.png"))
 
    tmp <- confint(sav)
    expect_equivalent(tmp[[1]]$random[1,], c(0.030713, 0.000224, 0.135284), tolerance=.tol[["var"]])
@@ -56,15 +58,17 @@ test_that("results are correct for the beta function model.", {
    sav <- selmodel(res, type="beta")
    out <- capture.output(print(sav))
 
-   expect_equivalent(coef(sav)$delta, c(0.4731131, 4.4613093), tolerance=.tol[["coef"]])
-   expect_equivalent(sav$se.delta, c(0.2352523, 2.1845971), tolerance=.tol[["se"]])
-   expect_equivalent(sav$LRT, 7.846906, tolerance=.tol[["test"]])
+   expect_equivalent(coef(sav)$delta, c(0.4731131, 4.4613162), tolerance=.tol[["coef"]])
+   expect_equivalent(sav$se.delta, c(0.2352481, 2.1841983), tolerance=.tol[["se"]])
+   expect_equivalent(sav$LRT, 7.846907, tolerance=.tol[["test"]])
    expect_identical(sav$LRTdf, 2L)
    expect_equivalent(sav$tau2, 0.00000243, tolerance=.tol[["var"]])
 
-   opar <- par(no.readonly=TRUE)
+   png(filename="images/test_misc_selmodel_2_test.png", res=200, width=1800, height=1600, type="cairo")
    plot(sav)
-   par(opar)
+   dev.off()
+
+   expect_true(.vistest("images/test_misc_selmodel_2_test.png", "images/test_misc_selmodel_2.png"))
 
    res <- rma(yi, sei^2, mods = ~ xi, method="ML")
 
@@ -72,7 +76,7 @@ test_that("results are correct for the beta function model.", {
    out <- capture.output(print(sav))
 
    expect_equivalent(coef(sav)$delta, c(0.4200973, 5.0959707), tolerance=.tol[["coef"]])
-   expect_equivalent(sav$se.delta, c(0.239128, 2.410997), tolerance=.tol[["se"]])
+   expect_equivalent(sav$se.delta, c(0.2391269, 2.4108796), tolerance=.tol[["se"]])
    expect_equivalent(sav$LRT, 9.044252, tolerance=.tol[["test"]])
    expect_identical(sav$LRTdf, 2L)
    expect_equivalent(sav$tau2, 0.00000193, tolerance=.tol[["var"]])
@@ -109,9 +113,11 @@ test_that("results are correct for the various exponential function models.", {
    expect_equivalent(c(sav1$delta, sav2$delta, sav3$delta, sav4$delta), c(3.162948, 2.656714, 3.339338, 1.458923), tolerance=.tol[["coef"]])
    expect_equivalent(c(sav1$se.delta, sav2$se.delta, sav3$se.delta, sav4$se.delta), c(2.988922, 2.347468, 2.388776, 1.393725), tolerance=.tol[["se"]])
 
-   opar <- par(no.readonly=TRUE)
+   png(filename="images/test_misc_selmodel_profile_1_test.png", res=200, width=1800, height=1600, type="cairo")
    tmp <- profile(sav1, progbar=FALSE)
-   par(opar)
+   dev.off()
+
+   expect_true(.vistest("images/test_misc_selmodel_profile_1_test.png", "images/test_misc_selmodel_profile_1.png"))
 
    expect_equivalent(tmp$ll, c(NA, -6.569986, -6.35659, -6.210436, -6.121035, -6.07939, -6.077928, -6.110356, -6.171488, -6.257068, -6.363607, -6.488238, -6.628599, -6.782733, -6.949015, -7.126075, -7.312763, -7.508097, -7.711241, -7.921472), tolerance=.tol[["fit"]])
 
@@ -161,4 +167,42 @@ test_that("results are correct for a pirori chosen step function models.", {
 
 })
 
+test_that("results are correct for a truncated distribution model.", {
+
+   expect_equivalent(TRUE, TRUE) # avoid 'Empty test' message
+
+   skip_on_cran()
+
+   dat <- dat.hackshaw1998
+   res <- rma(yi, vi, data=dat, method="ML")
+
+   sav <- selmodel(res, type="trunc")
+   out <- capture.output(print(sav))
+
+   expect_equivalent(coef(sav)$delta, 0.3818424, tolerance=.tol[["coef"]])
+   expect_equivalent(sav$se.delta, 0.2235527, tolerance=.tol[["se"]])
+   expect_equivalent(sav$LRT, 3.054457, tolerance=.tol[["test"]])
+   expect_identical(sav$LRTdf, 1L)
+   expect_equivalent(sav$tau2, 0.02677134, tolerance=.tol[["var"]])
+
+   tmp <- confint(sav)
+   expect_equivalent(tmp[[1]]$random[1,], c(0.026771, 0.001693, 0.099835), tolerance=.tol[["var"]])
+   expect_equivalent(tmp[[2]]$random[1,], c(0.381842, 0.108796, 1.116679), tolerance=.tol[["coef"]])
+
+   png(filename="images/test_misc_selmodel_profile_2_test.png", res=200, width=1800, height=1600, type="cairo")
+   tmp <- profile(sav, cline=TRUE, progbar=FALSE)
+   dev.off()
+
+   expect_true(.vistest("images/test_misc_selmodel_profile_2_test.png", "images/test_misc_selmodel_profile_2.png"))
+
+   res <- rma(yi, vi, data=dat, method="EE")
+
+   sav <- selmodel(res, type="truncest")
+   expect_equivalent(coef(sav)$delta, c(0.2336542, 0.4690409), tolerance=.tol[["coef"]])
+
+   sav <- selmodel(res, type="truncest", control=list(optimizer="mads"))
+   expect_equivalent(coef(sav)$delta, c(0.1802357, 0.4187099), tolerance=.tol[["coef"]])
+
+})
+
 rm(list=ls())
