@@ -2,7 +2,7 @@
 
 context("Checking misc: vif() function")
 
-source("tolerances.r") # read in tolerances
+source("settings.r")
 
 test_that("vif() works correctly for 'rma.uni' objects.", {
 
@@ -14,17 +14,19 @@ test_that("vif() works correctly for 'rma.uni' objects.", {
    out <- capture.output(print(sav))
 
    vifs <- c(length = 1.53710262575577, wic = 1.38604929927746, feedback = 1.64904565071108, info = 1.83396138431786, pers = 5.67803138275492, imag = 1.1553714953831, meta = 4.53327503733189)
-   expect_equivalent(sav$vif, vifs)
+   expect_equivalent(sav$vifs, vifs)
 
    sav <- vif(res, table=TRUE)
    out <- capture.output(print(sav))
 
-   expect_equivalent(sav$vif$vif[-1], vifs)
+   expect_equivalent(sav$vifs, vifs)
 
    sav <- vif(res, btt=2:3)
    out <- capture.output(print(sav))
 
    gvif <- 2.06507966959426
-   expect_equivalent(sav$gvif, gvif)
+   expect_equivalent(sav$vifs, gvif)
 
 })
+
+rm(list=ls())
