@@ -12,7 +12,7 @@ test_that("plot can be drawn.", {
 
    skip_on_cran()
 
-   opar <- par(no.readonly=TRUE)
+   png("images/test_plots_funnel_plot_variations_test.png", res=200, width=1800, height=1800, type="cairo")
 
    ### fit equal-effects model
    res <- rma(yi, vi, data=dat.hackshaw1998, measure="OR", method="EE")
@@ -26,7 +26,9 @@ test_that("plot can be drawn.", {
    funnel(res, yaxis="seinv", main="Inverse Standard Error")
    funnel(res, yaxis="vinv", main="Inverse Sampling Variance")
 
-   par(opar)
+   dev.off()
+
+   expect_true(.vistest("images/test_plots_funnel_plot_variations_test.png", "images/test_plots_funnel_plot_variations.png"))
 
 })
 
